// scoreboard.js - javascript function library for the Mallards Scoreboard.
//
//    Copyright (C) 2015-2017 Anders Lind, Erding Mallards e.V.
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// Version 3, April 14, 2017

webiopi().ready(function() {
	// #####################################################################################
	// ############################# Main controls section #################################
	// #####################################################################################
	// ############################## Inning Buttons #####################################
	var inningContent;
	inningContent = $("#inningContent");

	// Update the current inning label
	webiopi().callMacro("get_inning_label", [], getInningLabel);

	// Inning increment button
	var inningPlusButton = webiopi().createButton("InningUp", "Inning +", function() {
		webiopi().callMacro("update_inning_count",'up');
		webiopi().callMacro("get_inning_label", [], getInningLabel);
		webiopi().callMacro("get_player_info", [], setBatterInfo);
	});
	inningContent.append(inningPlusButton);

	// Dummy button to hold the current image label
	var showInningButton = webiopi().createButton("CurrInning", "---", getInningLabel);
	inningContent.append(showInningButton);

	// Inning decrement button
	var inningMinusButton = webiopi().createButton("InningDown", "Inning –", function() {
		webiopi().callMacro("update_inning_count",'down');
		webiopi().callMacro("get_inning_label", [], getInningLabel);
		webiopi().callMacro("get_player_info", [], setBatterInfo);
	});
	inningContent.append(inningMinusButton);

	// Functions needed by the inning label text
	function getInningLabel() {
		webiopi().callMacro("get_inning_label",[],setInningLabel);
	}
	function setInningLabel(macro, args, data) {
		webiopi().setLabel("CurrInning", data);
	}


	// ################################ Run Buttons #######################################
	var runContent;
	runContent = $("#runContent");

	// Run increment button
	var runPlusButton = webiopi().createButton("RunUp", "RUN", function() {
		webiopi().callMacro("update_inning_runs",'up');
		webiopi().callMacro("get_counter_value", 'G1', getRunsG1);
		webiopi().callMacro("get_counter_value", 'G2', getRunsG2);
		webiopi().callMacro("get_counter_value", 'G3', getRunsG3);
		webiopi().callMacro("get_counter_value", 'G4', getRunsG4);
		webiopi().callMacro("get_counter_value", 'G5', getRunsG5);
		webiopi().callMacro("get_counter_value", 'G6', getRunsG6);
		webiopi().callMacro("get_counter_value", 'G7', getRunsG7);
		webiopi().callMacro("get_counter_value", 'G8', getRunsG8);
		webiopi().callMacro("get_counter_value", 'G9', getRunsG9);
		webiopi().callMacro("get_counter_value", 'GX', getRunsGX);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
		webiopi().callMacro("get_counter_value", 'H1', getRunsH1);
		webiopi().callMacro("get_counter_value", 'H2', getRunsH2);
		webiopi().callMacro("get_counter_value", 'H3', getRunsH3);
		webiopi().callMacro("get_counter_value", 'H4', getRunsH4);
		webiopi().callMacro("get_counter_value", 'H5', getRunsH5);
		webiopi().callMacro("get_counter_value", 'H6', getRunsH6);
		webiopi().callMacro("get_counter_value", 'H7', getRunsH7);
		webiopi().callMacro("get_counter_value", 'H8', getRunsH8);
		webiopi().callMacro("get_counter_value", 'H9', getRunsH9);
		webiopi().callMacro("get_counter_value", 'HX', getRunsHX);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	runContent.append(runPlusButton);

	// Run decrement button
	var runMinusButton = webiopi().createButton("RunDown", "—", function() {
		webiopi().callMacro("update_inning_runs",'down');
		webiopi().callMacro("get_counter_value", 'G1', getRunsG1);
		webiopi().callMacro("get_counter_value", 'G2', getRunsG2);
		webiopi().callMacro("get_counter_value", 'G3', getRunsG3);
		webiopi().callMacro("get_counter_value", 'G4', getRunsG4);
		webiopi().callMacro("get_counter_value", 'G5', getRunsG5);
		webiopi().callMacro("get_counter_value", 'G6', getRunsG6);
		webiopi().callMacro("get_counter_value", 'G7', getRunsG7);
		webiopi().callMacro("get_counter_value", 'G8', getRunsG8);
		webiopi().callMacro("get_counter_value", 'G9', getRunsG9);
		webiopi().callMacro("get_counter_value", 'GX', getRunsGX);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
		webiopi().callMacro("get_counter_value", 'H1', getRunsH1);
		webiopi().callMacro("get_counter_value", 'H2', getRunsH2);
		webiopi().callMacro("get_counter_value", 'H3', getRunsH3);
		webiopi().callMacro("get_counter_value", 'H4', getRunsH4);
		webiopi().callMacro("get_counter_value", 'H5', getRunsH5);
		webiopi().callMacro("get_counter_value", 'H6', getRunsH6);
		webiopi().callMacro("get_counter_value", 'H7', getRunsH7);
		webiopi().callMacro("get_counter_value", 'H8', getRunsH8);
		webiopi().callMacro("get_counter_value", 'H9', getRunsH9);
		webiopi().callMacro("get_counter_value", 'HX', getRunsHX);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	runContent.append(runMinusButton);


	//  ################################ Hit Buttons #######################################
	var hitContent;
	hitContent = $("#hitContent");

	// Hit increment button
	var hitPlusButton = webiopi().createButton("HitUp", "HIT", function() {
		webiopi().callMacro("update_hits_count",'up');
		webiopi().callMacro("get_counter_value", 'GH', getHitsG);
		webiopi().callMacro("get_counter_value", 'HH', getHitsH);
	});
	hitContent.append(hitPlusButton);

	// Hit decrement button
	var hitMinusButton = webiopi().createButton("HitDown", "—", function() {
		webiopi().callMacro("update_hits_count",'down');
		webiopi().callMacro("get_counter_value", 'GH', getHitsG);
		webiopi().callMacro("get_counter_value", 'HH', getHitsH);
	});
	hitContent.append(hitMinusButton);

	//  ############################## Errors Buttons ######################################
	var errContent;
	errContent = $("#errContent");

	// Error increment button
	var errPlusButton = webiopi().createButton("ErrUp", "ERR", function() {
		webiopi().callMacro("update_error_count",'up');
		webiopi().callMacro("get_counter_value", 'GE', getErrorsG);
		webiopi().callMacro("get_counter_value", 'HE', getErrorsH);
	});
	errContent.append(errPlusButton);

	// Error decrement button
	var errMinusButton = webiopi().createButton("ErrDown", "—", function() {
		webiopi().callMacro("update_error_count",'down');
		webiopi().callMacro("get_counter_value", 'GE', getErrorsG);
		webiopi().callMacro("get_counter_value", 'HE', getErrorsH);
	});
	errContent.append(errMinusButton);

	//  ############################### Balls Button #######################################
	var ballContent;
	ballContent = $("#ballContent");

	// Balls increment button
	var ballButton = webiopi().createButton("Ball", "BALL", function() {
		webiopi().callMacro("update_balls_count",[]);
		webiopi().callMacro("get_counter_value", 'BALLS', setBalls);
	});
	ballContent.append(ballButton);

	function setBalls(macro, args, data) {
		if (data == "0") {
			$("#showBallsButton1").attr("class", "off");
			$("#showBallsButton2").attr("class", "off");
			$("#showBallsButton3").attr("class", "off");
		} else if (data == "1") {
			$("#showBallsButton1").attr("class", "on");
			$("#showBallsButton2").attr("class", "off");
			$("#showBallsButton3").attr("class", "off");
		} else if (data == "2") {
			$("#showBallsButton1").attr("class", "on");
			$("#showBallsButton2").attr("class", "on");
			$("#showBallsButton3").attr("class", "off");
		} else if (data == "3") {
			$("#showBallsButton1").attr("class", "on");
			$("#showBallsButton2").attr("class", "on");
			$("#showBallsButton3").attr("class", "on");
		}
	}

	//  ############################### Strikes Button #####################################
	var strikesContent;
	strikesContent = $("#strikesContent");

	// Strikes increment button
	var strikesButton = webiopi().createButton("Strike", "STRIKE", function() {
		webiopi().callMacro("update_strikes_count",[]);
		webiopi().callMacro("get_counter_value", 'STRIKES', setStrikes);
	});
	strikesContent.append(strikesButton);

	function setStrikes(macro, args, data) {
		if (data == "0") {
			$("#showStrikesButton1").attr("class", "off");
			$("#showStrikesButton2").attr("class", "off");
		} else if (data == "1") {
			$("#showStrikesButton1").attr("class", "on");
			$("#showStrikesButton2").attr("class", "off");
		} else if (data == "2") {
			$("#showStrikesButton1").attr("class", "on");
			$("#showStrikesButton2").attr("class", "on");
		}
	}

	//  ############################# Next Batter Button ###################################
	var nextBatterContent;
	nextBatterContent = $("#nextBatterContent");

	// Next Batter button
	var nextBatterButton = webiopi().createButton("NextBatter", "NEXT BATTER", function() {
		webiopi().callMacro("next_batter",[]);
		webiopi().callMacro("get_counter_value", 'BALLS', setBalls);
		webiopi().callMacro("get_counter_value", 'STRIKES', setStrikes);
		webiopi().callMacro("show_batter_info", []);
		webiopi().callMacro("get_player_info", [], getBatterInfo);
	});
	nextBatterContent.append(nextBatterButton);

	// Next Batter Info and minus button
	var nextBatterInfo = webiopi().createButton("NextBatterInfo", "-", function() {
		webiopi().callMacro("decrease_next_batter", []);
		webiopi().callMacro("get_player_info", [], getBatterInfo);
	});
	nextBatterContent.append(nextBatterInfo);
	
	// Functions to update the text of the next batter info button
	function getBatterInfo() {
		webiopi().callMacro("get_player_info", [], setBatterInfo);
	}
	
	function setBatterInfo(macro, args, data) {
		webiopi().setLabel('NextBatterInfo', data);
	}
	
	//  ############################### Outs Buttons #######################################
	var outsContent;
	outsContent = $("#outsContent");

	// Outs increment button
	var outsPlusButton = webiopi().createButton("OutUp", "OUT", function() {
		webiopi().callMacro("update_outs_count",[]);
		webiopi().callMacro("get_counter_value", 'OUTS', setOuts);
	});
	outsContent.append(outsPlusButton);

	function setOuts(macro, args, data) {
		if (data == "0") {
			$("#showOutsButton1").attr("class", "off");
			$("#showOutsButton2").attr("class", "off");
		} else if (data == "1") {
			$("#showOutsButton1").attr("class", "on");
			$("#showOutsButton2").attr("class", "off");
		} else if (data == "2") {
			$("#showOutsButton1").attr("class", "on");
			$("#showOutsButton2").attr("class", "on");
		}
	}

	// #####################################################################################
	// ########################### Detailed scoreboard section #############################
	// #####################################################################################

	// ############################### Runs Gast, 1. Inning ################################

	var contentG1;
	contentG1 = $("#contentG1");

	var runsG1_PlusButton = webiopi().createButton("RunsG1Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G1','up']);
		webiopi().callMacro("get_counter_value", 'G1', getRunsG1);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG1.append(runsG1_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG1Button = webiopi().createButton("RunsG1", "---", getRunsG1);
	contentG1.append(showRunsG1Button);
	
	var runsG1_MinusButton = webiopi().createButton("RunsG1Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G1','down']);
		webiopi().callMacro("get_counter_value", 'G1', getRunsG1);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG1.append(runsG1_MinusButton);

	// Functions needed by the current runs text
	function getRunsG1() {
		webiopi().callMacro("get_counter_value", 'G1', setRunsG1);
	}
	function setRunsG1(macro, args, data) {
		webiopi().setLabel("RunsG1", data);
	}

	// ############################### Runs Gast, 2. Inning ################################

	var contentG2;
	contentG2 = $("#contentG2");

	var runsG2_PlusButton = webiopi().createButton("RunsG2Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G2','up']);
		webiopi().callMacro("get_counter_value", 'G2', getRunsG2);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG2.append(runsG2_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG2Button = webiopi().createButton("RunsG2", "---", getRunsG2);
	contentG2.append(showRunsG2Button);
	
	var runsG2_MinusButton = webiopi().createButton("RunsG2Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G2','down']);
		webiopi().callMacro("get_counter_value", 'G2', getRunsG2);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG2.append(runsG2_MinusButton);

	// Functions needed by the current runs text
	function getRunsG2() {
		webiopi().callMacro("get_counter_value", 'G2', setRunsG2);
	}
	function setRunsG2(macro, args, data) {
		webiopi().setLabel("RunsG2", data);
	}

	// ############################### Runs Gast, 3. Inning ################################

	var contentG3;
	contentG3 = $("#contentG3");

	var runsG3_PlusButton = webiopi().createButton("RunsG3Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G3','up']);
		webiopi().callMacro("get_counter_value", 'G3', getRunsG3);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG3.append(runsG3_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG3Button = webiopi().createButton("RunsG3", "---", getRunsG3);
	contentG3.append(showRunsG3Button);
	
	var runsG3_MinusButton = webiopi().createButton("RunsG3Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G3','down']);
		webiopi().callMacro("get_counter_value", 'G3', getRunsG3);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG3.append(runsG3_MinusButton);

	// Functions needed by the current runs text
	function getRunsG3() {
		webiopi().callMacro("get_counter_value", 'G3', setRunsG3);
	}
	function setRunsG3(macro, args, data) {
		webiopi().setLabel("RunsG3", data);
	}

	// ############################### Runs Gast, 4. Inning ################################

	var contentG4;
	contentG4 = $("#contentG4");

	var runsG4_PlusButton = webiopi().createButton("RunsG4Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G4','up']);
		webiopi().callMacro("get_counter_value", 'G4', getRunsG4);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG4.append(runsG4_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG4Button = webiopi().createButton("RunsG4", "---", getRunsG4);
	contentG4.append(showRunsG4Button);
	
	var runsG4_MinusButton = webiopi().createButton("RunsG4Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G4','down']);
		webiopi().callMacro("get_counter_value", 'G4', getRunsG4);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG4.append(runsG4_MinusButton);

	// Functions needed by the current runs text
	function getRunsG4() {
		webiopi().callMacro("get_counter_value", 'G4', setRunsG4);
	}
	function setRunsG4(macro, args, data) {
		webiopi().setLabel("RunsG4", data);
	}

	// ############################### Runs Gast, 5. Inning ################################

	var contentG5;
	contentG5 = $("#contentG5");

	var runsG5_PlusButton = webiopi().createButton("RunsG5Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G5','up']);
		webiopi().callMacro("get_counter_value", 'G5', getRunsG5);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG5.append(runsG5_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG5Button = webiopi().createButton("RunsG5", "---", getRunsG5);
	contentG5.append(showRunsG5Button);
	
	var runsG5_MinusButton = webiopi().createButton("RunsG5Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G5','down']);
		webiopi().callMacro("get_counter_value", 'G5', getRunsG5);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG5.append(runsG5_MinusButton);

	// Functions needed by the current runs text
	function getRunsG5() {
		webiopi().callMacro("get_counter_value", 'G5', setRunsG5);
	}
	function setRunsG5(macro, args, data) {
		webiopi().setLabel("RunsG5", data);
	}

	// ############################### Runs Gast, 6. Inning ################################

	var contentG6;
	contentG6 = $("#contentG6");

	var runsG6_PlusButton = webiopi().createButton("RunsG6Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G6','up']);
		webiopi().callMacro("get_counter_value", 'G6', getRunsG6);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG6.append(runsG6_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG6Button = webiopi().createButton("RunsG6", "---", getRunsG6);
	contentG6.append(showRunsG6Button);
	
	var runsG6_MinusButton = webiopi().createButton("RunsG6Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G6','down']);
		webiopi().callMacro("get_counter_value", 'G6', getRunsG6);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG6.append(runsG6_MinusButton);

	// Functions needed by the current runs text
	function getRunsG6() {
		webiopi().callMacro("get_counter_value", 'G6', setRunsG6);
	}
	function setRunsG6(macro, args, data) {
		webiopi().setLabel("RunsG6", data);
	}

	// ############################### Runs Gast, 7. Inning ################################

	var contentG7;
	contentG7 = $("#contentG7");

	var runsG7_PlusButton = webiopi().createButton("RunsG7Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G7','up']);
		webiopi().callMacro("get_counter_value", 'G7', getRunsG7);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG7.append(runsG7_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG7Button = webiopi().createButton("RunsG7", "---", getRunsG7);
	contentG7.append(showRunsG7Button);
	
	var runsG7_MinusButton = webiopi().createButton("RunsG7Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G7','down']);
		webiopi().callMacro("get_counter_value", 'G7', getRunsG7);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG7.append(runsG7_MinusButton);

	// Functions needed by the current runs text
	function getRunsG7() {
		webiopi().callMacro("get_counter_value", 'G7', setRunsG7);
	}
	function setRunsG7(macro, args, data) {
		webiopi().setLabel("RunsG7", data);
	}

	// ############################### Runs Gast, 8. Inning ################################

	var contentG8;
	contentG8 = $("#contentG8");

	var runsG8_PlusButton = webiopi().createButton("RunsG8Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G8','up']);
		webiopi().callMacro("get_counter_value", 'G8', getRunsG8);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG8.append(runsG8_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG8Button = webiopi().createButton("RunsG8", "---", getRunsG8);
	contentG8.append(showRunsG8Button);
	
	var runsG8_MinusButton = webiopi().createButton("RunsG8Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G8','down']);
		webiopi().callMacro("get_counter_value", 'G8', getRunsG8);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG8.append(runsG8_MinusButton);

	// Functions needed by the current runs text
	function getRunsG8() {
		webiopi().callMacro("get_counter_value", 'G8', setRunsG8);
	}
	function setRunsG8(macro, args, data) {
		webiopi().setLabel("RunsG8", data);
	}

	// ############################### Runs Gast, 9. Inning ################################

	var contentG9;
	contentG9 = $("#contentG9");

	var runsG9_PlusButton = webiopi().createButton("RunsG9Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['G9','up']);
		webiopi().callMacro("get_counter_value", 'G9', getRunsG9);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG9.append(runsG9_PlusButton);

	// Dummy button to hold the current runs
	var showRunsG9Button = webiopi().createButton("RunsG9", "---", getRunsG9);
	contentG9.append(showRunsG9Button);
	
	var runsG9_MinusButton = webiopi().createButton("RunsG9Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['G9','down']);
		webiopi().callMacro("get_counter_value", 'G9', getRunsG9);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
	});
	contentG9.append(runsG9_MinusButton);

	// Functions needed by the current runs text
	function getRunsG9() {
		webiopi().callMacro("get_counter_value", 'G9', setRunsG9);
	}
	function setRunsG9(macro, args, data) {
		webiopi().setLabel("RunsG9", data);
	}

	// ############################## Runs Gast, Extra Innings ##############################
	// No update buttons, just the dummy button displaying the runs
	var contentGX;
	contentGX = $("#contentGX");

	// Dummy button to hold the current runs
	var showRunsGXButton = webiopi().createButton("RunsGX", "---", getRunsGX);
	contentGX.append(showRunsGXButton);
	
	// Functions needed by the current runs text
	function getRunsGX() {
		webiopi().callMacro("get_counter_value", 'GX', setRunsGX);
	}
	function setRunsGX(macro, args, data) {
		webiopi().setLabel("RunsGX", data);
	}

	// ################################# Runs Gast, Total  ##################################
	// No update buttons, just the dummy button displaying the runs
	var contentGR;
	contentGR = $("#contentGR");

	// Dummy button to hold the current runs
	var showRunsGRButton = webiopi().createButton("RunsGR", "---", getRunsGR);
	contentGR.append(showRunsGRButton);
	
	// Functions needed by the current runs text
	function getRunsGR() {
		webiopi().callMacro("get_counter_value", 'GR', setRunsGR);
	}
	function setRunsGR(macro, args, data) {
		webiopi().setLabel("RunsGR", data);
	}

	// ##################################### Hits Gast ######################################

	var contentGH;
	contentGH = $("#contentGH");

	var hitsG_PlusButton = webiopi().createButton("HitsGUp", "+", function() {
		webiopi().callMacro("update_given_hits_count",['G','up']);
		webiopi().callMacro("get_counter_value", 'GH', getHitsG);
	});
	contentGH.append(hitsG_PlusButton);

	// Dummy button to hold the current hits
	var showHitsGButton = webiopi().createButton("HitsG", "---", getHitsG);
	contentGH.append(showHitsGButton);
	
	var hitsG_MinusButton = webiopi().createButton("HitsGDown", "–", function() {
		webiopi().callMacro("update_given_hits_count",['G','down']);
		webiopi().callMacro("get_counter_value", 'GH', getHitsG);
	});
	contentGH.append(hitsG_MinusButton);

	// Functions needed by the current hits text
	function getHitsG() {
		webiopi().callMacro("get_counter_value", 'GH', setHitsG);
	}
	function setHitsG(macro, args, data) {
		webiopi().setLabel("HitsG", data);
	}

	// #################################### Errors Gast ####################################

	var contentGE;
	contentGE = $("#contentGE");

	var errorsG_PlusButton = webiopi().createButton("ErrGUp", "+", function() {
		webiopi().callMacro("update_given_error_count",['GE','up']);
		webiopi().callMacro("get_counter_value", 'GE', getErrorsG);
	});
	contentGE.append(errorsG_PlusButton);

	// Dummy button to hold the current errors
	var showErrorsGButton = webiopi().createButton("ErrG", "---", getErrorsG);
	contentGE.append(showErrorsGButton);
	
	var errorsG_MinusButton = webiopi().createButton("ErrGDown", "–", function() {
		webiopi().callMacro("update_given_error_count",['GE','down']);
		webiopi().callMacro("get_counter_value", 'GE', getErrorsG);
	});
	contentGE.append(errorsG_MinusButton);

	// Functions needed by the current errors text
	function getErrorsG() {
		webiopi().callMacro("get_counter_value", 'GE', setErrorsG);
	}
	function setErrorsG(macro, args, data) {
		webiopi().setLabel("ErrG", data);
	}


	// ############################### Runs Heim, 1. Inning ################################

	var contentH1;
	contentH1 = $("#contentH1");

	var runsH1_PlusButton = webiopi().createButton("RunsH1Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H1','up']);
		webiopi().callMacro("get_counter_value", 'H1', getRunsH1);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH1.append(runsH1_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH1Button = webiopi().createButton("RunsH1", "---", getRunsH1);
	contentH1.append(showRunsH1Button);
	
	var runsH1_MinusButton = webiopi().createButton("RunsH1Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H1','down']);
		webiopi().callMacro("get_counter_value", 'H1', getRunsH1);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH1.append(runsH1_MinusButton);

	// Functions needed by the current runs text
	function getRunsH1() {
		webiopi().callMacro("get_counter_value", 'H1', setRunsH1);
	}
	function setRunsH1(macro, args, data) {
		webiopi().setLabel("RunsH1", data);
	}

	// ############################### Runs Heim, 2. Inning ################################

	var contentH2;
	contentH2 = $("#contentH2");

	var runsH2_PlusButton = webiopi().createButton("RunsH2Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H2','up']);
		webiopi().callMacro("get_counter_value", 'H2', getRunsH2);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH2.append(runsH2_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH2Button = webiopi().createButton("RunsH2", "---", getRunsH2);
	contentH2.append(showRunsH2Button);
	
	var runsH2_MinusButton = webiopi().createButton("RunsH2Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H2','down']);
		webiopi().callMacro("get_counter_value", 'H2', getRunsH2);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH2.append(runsH2_MinusButton);

	// Functions needed by the current runs text
	function getRunsH2() {
		webiopi().callMacro("get_counter_value", 'H2', setRunsH2);
	}
	function setRunsH2(macro, args, data) {
		webiopi().setLabel("RunsH2", data);
	}

	// ############################### Runs Heim, 3. Inning ################################

	var contentH3;
	contentH3 = $("#contentH3");

	var runsH3_PlusButton = webiopi().createButton("RunsH3Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H3','up']);
		webiopi().callMacro("get_counter_value", 'H3', getRunsH3);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH3.append(runsH3_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH3Button = webiopi().createButton("RunsH3", "---", getRunsH3);
	contentH3.append(showRunsH3Button);
	
	var runsH3_MinusButton = webiopi().createButton("RunsH3Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H3','down']);
		webiopi().callMacro("get_counter_value", 'H3', getRunsH3);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH3.append(runsH3_MinusButton);

	// Functions needed by the current runs text
	function getRunsH3() {
		webiopi().callMacro("get_counter_value", 'H3', setRunsH3);
	}
	function setRunsH3(macro, args, data) {
		webiopi().setLabel("RunsH3", data);
	}

	// ############################### Runs Heim, 4. Inning ################################

	var contentH4;
	contentH4 = $("#contentH4");

	var runsH4_PlusButton = webiopi().createButton("RunsH4Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H4','up']);
		webiopi().callMacro("get_counter_value", 'H4', getRunsH4);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH4.append(runsH4_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH4Button = webiopi().createButton("RunsH4", "---", getRunsH4);
	contentH4.append(showRunsH4Button);
	
	var runsH4_MinusButton = webiopi().createButton("RunsH4Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H4','down']);
		webiopi().callMacro("get_counter_value", 'H4', getRunsH4);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH4.append(runsH4_MinusButton);

	// Functions needed by the current runs text
	function getRunsH4() {
		webiopi().callMacro("get_counter_value", 'H4', setRunsH4);
	}
	function setRunsH4(macro, args, data) {
		webiopi().setLabel("RunsH4", data);
	}

	// ############################### Runs Heim, 5. Inning ################################

	var contentH5;
	contentH5 = $("#contentH5");

	var runsH5_PlusButton = webiopi().createButton("RunsH5Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H5','up']);
		webiopi().callMacro("get_counter_value", 'H5', getRunsH5);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH5.append(runsH5_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH5Button = webiopi().createButton("RunsH5", "---", getRunsH5);
	contentH5.append(showRunsH5Button);
	
	var runsH5_MinusButton = webiopi().createButton("RunsH5Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H5','down']);
		webiopi().callMacro("get_counter_value", 'H5', getRunsH5);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH5.append(runsH5_MinusButton);

	// Functions needed by the current runs text
	function getRunsH5() {
		webiopi().callMacro("get_counter_value", 'H5', setRunsH5);
	}
	function setRunsH5(macro, args, data) {
		webiopi().setLabel("RunsH5", data);
	}

	// ############################### Runs Heim, 6. Inning ################################

	var contentH6;
	contentH6 = $("#contentH6");

	var runsH6_PlusButton = webiopi().createButton("RunsH6Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H6','up']);
		webiopi().callMacro("get_counter_value", 'H6', getRunsH6);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH6.append(runsH6_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH6Button = webiopi().createButton("RunsH6", "---", getRunsH6);
	contentH6.append(showRunsH6Button);
	
	var runsH6_MinusButton = webiopi().createButton("RunsH6Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H6','down']);
		webiopi().callMacro("get_counter_value", 'H6', getRunsH6);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH6.append(runsH6_MinusButton);

	// Functions needed by the current runs text
	function getRunsH6() {
		webiopi().callMacro("get_counter_value", 'H6', setRunsH6);
	}
	function setRunsH6(macro, args, data) {
		webiopi().setLabel("RunsH6", data);
	}

	// ############################### Runs Heim, 7. Inning ################################

	var contentH7;
	contentH7 = $("#contentH7");

	var runsH7_PlusButton = webiopi().createButton("RunsH7Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H7','up']);
		webiopi().callMacro("get_counter_value", 'H7', getRunsH7);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH7.append(runsH7_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH7Button = webiopi().createButton("RunsH7", "---", getRunsH7);
	contentH7.append(showRunsH7Button);
	
	var runsH7_MinusButton = webiopi().createButton("RunsH7Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H7','down']);
		webiopi().callMacro("get_counter_value", 'H7', getRunsH7);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH7.append(runsH7_MinusButton);

	// Functions needed by the current runs text
	function getRunsH7() {
		webiopi().callMacro("get_counter_value", 'H7', setRunsH7);
	}
	function setRunsH7(macro, args, data) {
		webiopi().setLabel("RunsH7", data);
	}

	// ############################### Runs Heim, 8. Inning ################################

	var contentH8;
	contentH8 = $("#contentH8");

	var runsH8_PlusButton = webiopi().createButton("RunsH8Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H8','up']);
		webiopi().callMacro("get_counter_value", 'H8', getRunsH8);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH8.append(runsH8_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH8Button = webiopi().createButton("RunsH8", "---", getRunsH8);
	contentH8.append(showRunsH8Button);
	
	var runsH8_MinusButton = webiopi().createButton("RunsH8Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H8','down']);
		webiopi().callMacro("get_counter_value", 'H8', getRunsH8);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH8.append(runsH8_MinusButton);

	// Functions needed by the current runs text
	function getRunsH8() {
		webiopi().callMacro("get_counter_value", 'H8', setRunsH8);
	}
	function setRunsH8(macro, args, data) {
		webiopi().setLabel("RunsH8", data);
	}

	// ############################### Runs Heim, 9. Inning ################################

	var contentH9;
	contentH9 = $("#contentH9");

	var runsH9_PlusButton = webiopi().createButton("RunsH9Up", "+", function() {
		webiopi().callMacro("update_given_run_counter",['H9','up']);
		webiopi().callMacro("get_counter_value", 'H9', getRunsH9);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH9.append(runsH9_PlusButton);

	// Dummy button to hold the current runs
	var showRunsH9Button = webiopi().createButton("RunsH9", "---", getRunsH9);
	contentH9.append(showRunsH9Button);
	
	var runsH9_MinusButton = webiopi().createButton("RunsH9Down", "–", function() {
		webiopi().callMacro("update_given_run_counter",['H9','down']);
		webiopi().callMacro("get_counter_value", 'H9', getRunsH9);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
	});
	contentH9.append(runsH9_MinusButton);

	// Functions needed by the current runs text
	function getRunsH9() {
		webiopi().callMacro("get_counter_value", 'H9', setRunsH9);
	}
	function setRunsH9(macro, args, data) {
		webiopi().setLabel("RunsH9", data);
	}

	// ############################## Runs Heim, Extra Innings ##############################
	// No update buttons, just the dummy button displaying the runs
	var contentHX;
	contentHX = $("#contentHX");

	// Dummy button to hold the current runs
	var showRunsHXButton = webiopi().createButton("RunsHX", "---", getRunsHX);
	contentHX.append(showRunsHXButton);
	
	// Functions needed by the current runs text
	function getRunsHX() {
		webiopi().callMacro("get_counter_value", 'HX', setRunsHX);
	}
	function setRunsHX(macro, args, data) {
		webiopi().setLabel("RunsHX", data);
	}

	// ################################# Runs Heim, Total  ##################################
	// No update buttons, just the dummy button displaying the runs
	var contentHR;
	contentHR = $("#contentHR");

	// Dummy button to hold the current runs
	var showRunsHRButton = webiopi().createButton("RunsHR", "---", getRunsHR);
	contentHR.append(showRunsHRButton);
	
	// Functions needed by the current runs text
	function getRunsHR() {
		webiopi().callMacro("get_counter_value", 'HR', setRunsHR);
	}
	function setRunsHR(macro, args, data) {
		webiopi().setLabel("RunsHR", data);
	}

	// ##################################### Hits Heim ######################################

	var contentHH;
	contentHH = $("#contentHH");

	var hitsH_PlusButton = webiopi().createButton("HitsHUp", "+", function() {
		webiopi().callMacro("update_given_hits_count",['H','up']);
		webiopi().callMacro("get_counter_value", 'HH', getHitsH);
	});
	contentHH.append(hitsH_PlusButton);

	// Dummy button to hold the current hits
	var showHitsHButton = webiopi().createButton("HitsH", "---", getHitsH);
	contentHH.append(showHitsHButton);
	
	var hitsH_MinusButton = webiopi().createButton("HitsHDown", "–", function() {
		webiopi().callMacro("update_given_hits_count",['H','down']);
		webiopi().callMacro("get_counter_value", 'HH', getHitsH);
	});
	contentHH.append(hitsH_MinusButton);

	// Functions needed by the current hits text
	function getHitsH() {
		webiopi().callMacro("get_counter_value", 'HH', setHitsH);
	}
	function setHitsH(macro, args, data) {
		webiopi().setLabel("HitsH", data);
	}

	// #################################### Errors Heim ####################################

	var contentHE;
	contentHE = $("#contentHE");

	var errorsH_PlusButton = webiopi().createButton("ErrHUp", "+", function() {
		webiopi().callMacro("update_given_error_count",['HE','up']);
		webiopi().callMacro("get_counter_value", 'HE', getErrorsH);
	});
	contentHE.append(errorsH_PlusButton);

	// Dummy button to hold the current errors
	var showErrorsHButton = webiopi().createButton("ErrH", "---", getErrorsH);
	contentHE.append(showErrorsHButton);
	
	var errorsH_MinusButton = webiopi().createButton("ErrHDown", "–", function() {
		webiopi().callMacro("update_given_error_count",['HE','down']);
		webiopi().callMacro("get_counter_value", 'HE', getErrorsH);
	});
	contentHE.append(errorsH_MinusButton);

	// Functions needed by the current errors text
	function getErrorsH() {
		webiopi().callMacro("get_counter_value", 'HE', setErrorsH);
	}
	function setErrorsH(macro, args, data) {
		webiopi().setLabel("ErrH", data);
	}

	// #####################################################################################
	// ############################### Display mode section ################################
	// #####################################################################################

	// Timer used to auto-refresh the time display. First just create it doing nothing
	var timerId = setInterval(() => null, 30000);
	
	// Button 0 - Time mode
	var contentMode0;
	contentMode0 = $("#contentMode0");

	var mode0Button = webiopi().createButton("Mode0", " ", function() {
		webiopi().callMacro("set_display_mode",'0');
		webiopi().callMacro("get_display_mode", [], getDispMode);
		sessionStorage.setItem("displayMode","0");
	});
	contentMode0.append(mode0Button);

	function getDispMode() {
		webiopi().callMacro("get_display_mode", [], setLabelD0);
		webiopi().callMacro("get_display_mode", [], setLabelD1);
		webiopi().callMacro("get_display_mode", [], setLabelD2);
		webiopi().callMacro("get_display_mode", [], setLabelD4);
	}
	function setLabelD0(macro, args, data) {
		if (data == 0)
		{
			webiopi().setLabel("Mode0", "X");
			if (sessionStorage.displayMode == "0") {
				timerId = setInterval(function() {
					webiopi().callMacro("show_time","setInterval");
				}, 500);
			}
		} else {
			webiopi().setLabel("Mode0", " ");
		}
	}

	// Button 1 - Baseball mode
	var contentMode1;
	contentMode1 = $("#contentMode1");

	var mode1Button = webiopi().createButton("Mode1", "X", function() {
		webiopi().callMacro("set_display_mode",'1');
		webiopi().callMacro("get_display_mode", [], getDispMode);
		sessionStorage.setItem("displayMode","1");
		clearInterval(timerId);
	});
	contentMode1.append(mode1Button);

	function getDispMode() {
		webiopi().callMacro("get_display_mode", [], setLabelD0);
		webiopi().callMacro("get_display_mode", [], setLabelD1);
		webiopi().callMacro("get_display_mode", [], setLabelD2);
		webiopi().callMacro("get_display_mode", [], setLabelD4);
	}
	function setLabelD1(macro, args, data) {
		if (data == 1) {
			webiopi().setLabel("Mode1", "X");
		} else {
			webiopi().setLabel("Mode1", " ");
		}
	}

	// Button 2 - Teeball mode
	var contentMode2;
	contentMode2 = $("#contentMode2");

	var mode2Button = webiopi().createButton("Mode2", " ", function() {
		webiopi().callMacro("set_display_mode",'2');
		webiopi().callMacro("get_display_mode", [], getDispMode);
		sessionStorage.setItem("displayMode","2");
		clearInterval(timerId);
	});
	contentMode2.append(mode2Button);

	function getDispMode() {
		webiopi().callMacro("get_display_mode", [], setLabelD0);
		webiopi().callMacro("get_display_mode", [], setLabelD1);
		webiopi().callMacro("get_display_mode", [], setLabelD2);
		webiopi().callMacro("get_display_mode", [], setLabelD4);
	}
	function setLabelD2(macro, args, data) {
		if (data == 2)
		{
			webiopi().setLabel("Mode2", "X");
		} else {
			webiopi().setLabel("Mode2", " ");
		}
	}

	// Button 4 - Homerun animation
	// There's no button 3, as display mode 3 is only shown on startup!
	var contentMode4;
	contentMode4 = $("#contentMode4");

	var mode4Button = webiopi().createButton("Mode4", " ", function() {
		webiopi().callMacro("set_display_mode",'4');
		webiopi().callMacro("get_display_mode", [], getDispMode);
		sessionStorage.setItem("displayMode","4");
		clearInterval(timerId);
	});
	contentMode4.append(mode4Button);

	function getDispMode() {
		webiopi().callMacro("get_display_mode", [], setLabelD0);
		webiopi().callMacro("get_display_mode", [], setLabelD1);
		webiopi().callMacro("get_display_mode", [], setLabelD2);
		webiopi().callMacro("get_display_mode", [], setLabelD4);
	}
	function setLabelD4(macro, args, data) {
		if (data == 4)
		{
			webiopi().setLabel("Mode4", "X");
		} else {
			webiopi().setLabel("Mode4", " ");
		}
	}
	// #####################################################################################
	// ############################### Game control section ################################
	// #####################################################################################

	// ################################# Start a new game ##################################
	var contentNewGame;
	contentNewGame = $("#contentNewGame");

	var newGameButton = webiopi().createButton("NewGame", "Neues Spiel beginnen", function() {
		var newGameResponse = confirm("Neues Spiel beginnen? Alle Zähler werden zurückgesetzt!");
		if (newGameResponse == true) {
			webiopi().callMacro("start_new_game", []);
			webiopi().callMacro("get_player_info", [], setBatterInfo);
			window.location.reload(true);
		} 
	});
	contentNewGame.append(newGameButton);

	// ################################### Set the clock ###################################
	var contentSetClock;
	contentSetClock = $("#contentSetClock");

	var setTimeButton = webiopi().createButton("SetClock", "Zeit stellen", function() {
		var setTimeResponse = prompt("Gib die aktuelle Zeit ein. Du musst dieses Format verwenden: \n12:22.", "hh:mm");
		if (setTimeResponse != null) {
			webiopi().callMacro("set_time", setTimeResponse);
		}
	});
	contentSetClock.append(setTimeButton);

	// ############################# Restart the scoreboard ################################
	var contentRestart;
	contentRestart = $("#contentRestart");

	var restartButton = webiopi().createButton("Restart", "Scoreboard neu starten", function() {
		var restartResponse = confirm("Scoreboard neu starten? Alle Zeiger und Einstellungen gehen verloren und die Verbindung zum Browser wird für ein paar Minuten nicht verfügbar sein.");
		if (restartResponse == true) {
			sessionStorage.clear();
			webiopi().callMacro("restart_scoreboard", []);
		} 
	});
	contentRestart.append(restartButton);


	// ############################ Shut down the scoreboard ###############################
	var contentShutdown;
	contentShutdown = $("#contentShutdown");

	var shutdownButton = webiopi().createButton("Shutdown", "Scoreboard abschalten", function() {
		var shutdownResponse = confirm("Scoreboard komplett abschalten? Du musst den Hauptschalter am Scoreboard aus- und einschalten um das Scoreboard wieder zu verwenden.");
		if (shutdownResponse == true) {
			sessionStorage.clear();
			webiopi().callMacro("shutdown_scoreboard", []);
		} 
	});
	contentShutdown.append(shutdownButton);


	// ############# Refresh all label buttons if user refreshes the page ##################
	// ############# Also attempt to set the pi's time from the client #####################

	$(document).ready(function(){
		webiopi().callMacro("get_counter_value", 'G1', getRunsG1);
		webiopi().callMacro("get_counter_value", 'G2', getRunsG2);
		webiopi().callMacro("get_counter_value", 'G3', getRunsG3);
		webiopi().callMacro("get_counter_value", 'G4', getRunsG4);
		webiopi().callMacro("get_counter_value", 'G5', getRunsG5);
		webiopi().callMacro("get_counter_value", 'G6', getRunsG6);
		webiopi().callMacro("get_counter_value", 'G7', getRunsG7);
		webiopi().callMacro("get_counter_value", 'G8', getRunsG8);
		webiopi().callMacro("get_counter_value", 'G9', getRunsG9);
		webiopi().callMacro("get_counter_value", 'GX', getRunsGX);
		webiopi().callMacro("get_counter_value", 'GR', getRunsGR);
		webiopi().callMacro("get_counter_value", 'GH', getHitsG);
		webiopi().callMacro("get_counter_value", 'GE', getErrorsG);
		webiopi().callMacro("get_counter_value", 'H1', getRunsH1);
		webiopi().callMacro("get_counter_value", 'H2', getRunsH2);
		webiopi().callMacro("get_counter_value", 'H3', getRunsH3);
		webiopi().callMacro("get_counter_value", 'H4', getRunsH4);
		webiopi().callMacro("get_counter_value", 'H5', getRunsH5);
		webiopi().callMacro("get_counter_value", 'H6', getRunsH6);
		webiopi().callMacro("get_counter_value", 'H7', getRunsH7);
		webiopi().callMacro("get_counter_value", 'H8', getRunsH8);
		webiopi().callMacro("get_counter_value", 'H9', getRunsH9);
		webiopi().callMacro("get_counter_value", 'HX', getRunsHX);
		webiopi().callMacro("get_counter_value", 'HR', getRunsHR);
		webiopi().callMacro("get_counter_value", 'HH', getHitsH);
		webiopi().callMacro("get_counter_value", 'HE', getErrorsH);
		webiopi().callMacro("get_counter_value", 'BALLS', setBalls);
		webiopi().callMacro("get_counter_value", 'STRIKES', setStrikes);
		webiopi().callMacro("get_counter_value", 'OUTS', setOuts);
		webiopi().callMacro("get_display_mode", [], setLabelD0);
		webiopi().callMacro("get_display_mode", [], setLabelD1);
		webiopi().callMacro("get_display_mode", [], setLabelD2);
		webiopi().callMacro("get_player_info", [], setBatterInfo);

		var DateTime = new Date();
		var strHours = DateTime.getHours();
		var strMinutes = DateTime.getMinutes();
		if (DateTime != null) {
			webiopi().callMacro("set_time", strHours + ":" + strMinutes);
		}
	});
});

// ############# Entry of player information ##################
// The definitions of the various input fields are done in the
// index.html file. This section only handles the update of the
// global variables when the user clicks on "OK".
function updatePlayerG1 () {
	var playerNumberG1 = parseInt(document.getElementById("pl_num_G1").value);
	var playerGivenNameG1 = document.getElementById("pl_gname_G1").value;
	var playerFamilyNameG1 = document.getElementById("pl_fname_G1").value;
	var playerPositionG1 = document.getElementById("pl_pos_G1").value;
	var playerHitsG1 = parseInt(document.getElementById("pl_hits_G1").value);
	var playerAtBatsG1 = parseInt(document.getElementById("pl_atbats_G1").value);
	document.getElementById("pl_num_G1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G1").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G1',playerNumberG1,playerGivenNameG1,playerFamilyNameG1,playerPositionG1,playerHitsG1,playerAtBatsG1]);
};
function updatePlayerG2 () {
	var playerNumberG2 = parseInt(document.getElementById("pl_num_G2").value);
	var playerGivenNameG2 = document.getElementById("pl_gname_G2").value;
	var playerFamilyNameG2 = document.getElementById("pl_fname_G2").value;
	var playerPositionG2 = document.getElementById("pl_pos_G2").value;
	var playerHitsG2 = parseInt(document.getElementById("pl_hits_G2").value);
	var playerAtBatsG2 = parseInt(document.getElementById("pl_atbats_G2").value);
	document.getElementById("pl_num_G2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G2").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G2',playerNumberG2,playerGivenNameG2,playerFamilyNameG2,playerPositionG2,playerHitsG2,playerAtBatsG2]);
};
function updatePlayerG3 () {
	var playerNumberG3 = parseInt(document.getElementById("pl_num_G3").value);
	var playerGivenNameG3 = document.getElementById("pl_gname_G3").value;
	var playerFamilyNameG3 = document.getElementById("pl_fname_G3").value;
	var playerPositionG3 = document.getElementById("pl_pos_G3").value;
	var playerHitsG3 = parseInt(document.getElementById("pl_hits_G3").value);
	var playerAtBatsG3 = parseInt(document.getElementById("pl_atbats_G3").value);
	document.getElementById("pl_num_G3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G3").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G3',playerNumberG3,playerGivenNameG3,playerFamilyNameG3,playerPositionG3,playerHitsG3,playerAtBatsG3]);
};
function updatePlayerG4 () {
	var playerNumberG4 = parseInt(document.getElementById("pl_num_G4").value);
	var playerGivenNameG4 = document.getElementById("pl_gname_G4").value;
	var playerFamilyNameG4 = document.getElementById("pl_fname_G4").value;
	var playerPositionG4 = document.getElementById("pl_pos_G4").value;
	var playerHitsG4 = parseInt(document.getElementById("pl_hits_G4").value);
	var playerAtBatsG4 = parseInt(document.getElementById("pl_atbats_G4").value);
	document.getElementById("pl_num_G4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G4").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G4',playerNumberG4,playerGivenNameG4,playerFamilyNameG4,playerPositionG4,playerHitsG4,playerAtBatsG4]);
};
function updatePlayerG5 () {
	var playerNumberG5 = parseInt(document.getElementById("pl_num_G5").value);
	var playerGivenNameG5 = document.getElementById("pl_gname_G5").value;
	var playerFamilyNameG5 = document.getElementById("pl_fname_G5").value;
	var playerPositionG5 = document.getElementById("pl_pos_G5").value;
	var playerHitsG5 = parseInt(document.getElementById("pl_hits_G5").value);
	var playerAtBatsG5 = parseInt(document.getElementById("pl_atbats_G5").value);
	document.getElementById("pl_num_G5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G5").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G5',playerNumberG5,playerGivenNameG5,playerFamilyNameG5,playerPositionG5,playerHitsG5,playerAtBatsG5]);
};
function updatePlayerG6 () {
	var playerNumberG6 = parseInt(document.getElementById("pl_num_G6").value);
	var playerGivenNameG6 = document.getElementById("pl_gname_G6").value;
	var playerFamilyNameG6 = document.getElementById("pl_fname_G6").value;
	var playerPositionG6 = document.getElementById("pl_pos_G6").value;
	var playerHitsG6 = parseInt(document.getElementById("pl_hits_G6").value);
	var playerAtBatsG6 = parseInt(document.getElementById("pl_atbats_G6").value);
	document.getElementById("pl_num_G6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G6").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G6',playerNumberG6,playerGivenNameG6,playerFamilyNameG6,playerPositionG6,playerHitsG6,playerAtBatsG6]);
};
function updatePlayerG7 () {
	var playerNumberG7 = parseInt(document.getElementById("pl_num_G7").value);
	var playerGivenNameG7 = document.getElementById("pl_gname_G7").value;
	var playerFamilyNameG7 = document.getElementById("pl_fname_G7").value;
	var playerPositionG7 = document.getElementById("pl_pos_G7").value;
	var playerHitsG7 = parseInt(document.getElementById("pl_hits_G7").value);
	var playerAtBatsG7 = parseInt(document.getElementById("pl_atbats_G7").value);
	document.getElementById("pl_num_G7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G7").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G7',playerNumberG7,playerGivenNameG7,playerFamilyNameG7,playerPositionG7,playerHitsG7,playerAtBatsG7]);
};
function updatePlayerG8 () {
	var playerNumberG8 = parseInt(document.getElementById("pl_num_G8").value);
	var playerGivenNameG8 = document.getElementById("pl_gname_G8").value;
	var playerFamilyNameG8 = document.getElementById("pl_fname_G8").value;
	var playerPositionG8 = document.getElementById("pl_pos_G8").value;
	var playerHitsG8 = parseInt(document.getElementById("pl_hits_G8").value);
	var playerAtBatsG8 = parseInt(document.getElementById("pl_atbats_G8").value);
	document.getElementById("pl_num_G8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G8").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G8',playerNumberG8,playerGivenNameG8,playerFamilyNameG8,playerPositionG8,playerHitsG8,playerAtBatsG8]);
};
function updatePlayerG9 () {
	var playerNumberG9 = parseInt(document.getElementById("pl_num_G9").value);
	var playerGivenNameG9 = document.getElementById("pl_gname_G9").value;
	var playerFamilyNameG9 = document.getElementById("pl_fname_G9").value;
	var playerPositionG9 = document.getElementById("pl_pos_G9").value;
	var playerHitsG9 = parseInt(document.getElementById("pl_hits_G9").value);
	var playerAtBatsG9 = parseInt(document.getElementById("pl_atbats_G9").value);
	document.getElementById("pl_num_G9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_G9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_G9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_G9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_G9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_G9").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['G9',playerNumberG9,playerGivenNameG9,playerFamilyNameG9,playerPositionG9,playerHitsG9,playerAtBatsG9]);
};
function updatePlayerH1 () {
	var playerNumberH1 = parseInt(document.getElementById("pl_num_H1").value);
	var playerGivenNameH1 = document.getElementById("pl_gname_H1").value;
	var playerFamilyNameH1 = document.getElementById("pl_fname_H1").value;
	var playerPositionH1 = document.getElementById("pl_pos_H1").value;
	var playerHitsH1 = parseInt(document.getElementById("pl_hits_H1").value);
	var playerAtBatsH1 = parseInt(document.getElementById("pl_atbats_H1").value);
	document.getElementById("pl_num_H1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H1").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H1").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H1',playerNumberH1,playerGivenNameH1,playerFamilyNameH1,playerPositionH1,playerHitsH1,playerAtBatsH1]);
};
function updatePlayerH2 () {
	var playerNumberH2 = parseInt(document.getElementById("pl_num_H2").value);
	var playerGivenNameH2 = document.getElementById("pl_gname_H2").value;
	var playerFamilyNameH2 = document.getElementById("pl_fname_H2").value;
	var playerPositionH2 = document.getElementById("pl_pos_H2").value;
	var playerHitsH2 = parseInt(document.getElementById("pl_hits_H2").value);
	var playerAtBatsH2 = parseInt(document.getElementById("pl_atbats_H2").value);
	document.getElementById("pl_num_H2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H2").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H2").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H2',playerNumberH2,playerGivenNameH2,playerFamilyNameH2,playerPositionH2,playerHitsH2,playerAtBatsH2]);
};
function updatePlayerH3 () {
	var playerNumberH3 = parseInt(document.getElementById("pl_num_H3").value);
	var playerGivenNameH3 = document.getElementById("pl_gname_H3").value;
	var playerFamilyNameH3 = document.getElementById("pl_fname_H3").value;
	var playerPositionH3 = document.getElementById("pl_pos_H3").value;
	var playerHitsH3 = parseInt(document.getElementById("pl_hits_H3").value);
	var playerAtBatsH3 = parseInt(document.getElementById("pl_atbats_H3").value);
	document.getElementById("pl_num_H3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H3").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H3").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H3',playerNumberH3,playerGivenNameH3,playerFamilyNameH3,playerPositionH3,playerHitsH3,playerAtBatsH3]);
};
function updatePlayerH4 () {
	var playerNumberH4 = parseInt(document.getElementById("pl_num_H4").value);
	var playerGivenNameH4 = document.getElementById("pl_gname_H4").value;
	var playerFamilyNameH4 = document.getElementById("pl_fname_H4").value;
	var playerPositionH4 = document.getElementById("pl_pos_H4").value;
	var playerHitsH4 = parseInt(document.getElementById("pl_hits_H4").value);
	var playerAtBatsH4 = parseInt(document.getElementById("pl_atbats_H4").value);
	document.getElementById("pl_num_H4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H4").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H4").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H4',playerNumberH4,playerGivenNameH4,playerFamilyNameH4,playerPositionH4,playerHitsH4,playerAtBatsH4]);
};
function updatePlayerH5 () {
	var playerNumberH5 = parseInt(document.getElementById("pl_num_H5").value);
	var playerGivenNameH5 = document.getElementById("pl_gname_H5").value;
	var playerFamilyNameH5 = document.getElementById("pl_fname_H5").value;
	var playerPositionH5 = document.getElementById("pl_pos_H5").value;
	var playerHitsH5 = parseInt(document.getElementById("pl_hits_H5").value);
	var playerAtBatsH5 = parseInt(document.getElementById("pl_atbats_H5").value);
	document.getElementById("pl_num_H5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H5").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H5").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H5',playerNumberH5,playerGivenNameH5,playerFamilyNameH5,playerPositionH5,playerHitsH5,playerAtBatsH5]);
};
function updatePlayerH6 () {
	var playerNumberH6 = parseInt(document.getElementById("pl_num_H6").value);
	var playerGivenNameH6 = document.getElementById("pl_gname_H6").value;
	var playerFamilyNameH6 = document.getElementById("pl_fname_H6").value;
	var playerPositionH6 = document.getElementById("pl_pos_H6").value;
	var playerHitsH6 = parseInt(document.getElementById("pl_hits_H6").value);
	var playerAtBatsH6 = parseInt(document.getElementById("pl_atbats_H6").value);
	document.getElementById("pl_num_H6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H6").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H6").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H6',playerNumberH6,playerGivenNameH6,playerFamilyNameH6,playerPositionH6,playerHitsH6,playerAtBatsH6]);
};
function updatePlayerH7 () {
	var playerNumberH7 = parseInt(document.getElementById("pl_num_H7").value);
	var playerGivenNameH7 = document.getElementById("pl_gname_H7").value;
	var playerFamilyNameH7 = document.getElementById("pl_fname_H7").value;
	var playerPositionH7 = document.getElementById("pl_pos_H7").value;
	var playerHitsH7 = parseInt(document.getElementById("pl_hits_H7").value);
	var playerAtBatsH7 = parseInt(document.getElementById("pl_atbats_H7").value);
	document.getElementById("pl_num_H7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H7").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H7").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H7',playerNumberH7,playerGivenNameH7,playerFamilyNameH7,playerPositionH7,playerHitsH7,playerAtBatsH7]);
};
function updatePlayerH8 () {
	var playerNumberH8 = parseInt(document.getElementById("pl_num_H8").value);
	var playerGivenNameH8 = document.getElementById("pl_gname_H8").value;
	var playerFamilyNameH8 = document.getElementById("pl_fname_H8").value;
	var playerPositionH8 = document.getElementById("pl_pos_H8").value;
	var playerHitsH8 = parseInt(document.getElementById("pl_hits_H8").value);
	var playerAtBatsH8 = parseInt(document.getElementById("pl_atbats_H8").value);
	document.getElementById("pl_num_H8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H8").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H8").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H8',playerNumberH8,playerGivenNameH8,playerFamilyNameH8,playerPositionH8,playerHitsH8,playerAtBatsH8]);
};
function updatePlayerH9 () {
	var playerNumberH9 = parseInt(document.getElementById("pl_num_H9").value);
	var playerGivenNameH9 = document.getElementById("pl_gname_H9").value;
	var playerFamilyNameH9 = document.getElementById("pl_fname_H9").value;
	var playerPositionH9 = document.getElementById("pl_pos_H9").value;
	var playerHitsH9 = parseInt(document.getElementById("pl_hits_H9").value);
	var playerAtBatsH9 = parseInt(document.getElementById("pl_atbats_H9").value);
	document.getElementById("pl_num_H9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_gname_H9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_fname_H9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_pos_H9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_hits_H9").style.backgroundColor = "PaleGreen";
	document.getElementById("pl_atbats_H9").style.backgroundColor = "PaleGreen";
	webiopi().callMacro("update_player", ['H9',playerNumberH9,playerGivenNameH9,playerFamilyNameH9,playerPositionH9,playerHitsH9,playerAtBatsH9]);
};


window.onload = function () {
	// Send the player data to the sbfunc.py script when the OK button is clicked
	document.getElementById("setPlayerG1").onclick = updatePlayerG1;
	document.getElementById("setPlayerG2").onclick = updatePlayerG2;
	document.getElementById("setPlayerG3").onclick = updatePlayerG3;
	document.getElementById("setPlayerG4").onclick = updatePlayerG4;
	document.getElementById("setPlayerG5").onclick = updatePlayerG5;
	document.getElementById("setPlayerG6").onclick = updatePlayerG6;
	document.getElementById("setPlayerG7").onclick = updatePlayerG7;
	document.getElementById("setPlayerG8").onclick = updatePlayerG8;
	document.getElementById("setPlayerG9").onclick = updatePlayerG9;
	document.getElementById("setPlayerH1").onclick = updatePlayerH1;
	document.getElementById("setPlayerH2").onclick = updatePlayerH2;
	document.getElementById("setPlayerH3").onclick = updatePlayerH3;
	document.getElementById("setPlayerH4").onclick = updatePlayerH4;
	document.getElementById("setPlayerH5").onclick = updatePlayerH5;
	document.getElementById("setPlayerH6").onclick = updatePlayerH6;
	document.getElementById("setPlayerH7").onclick = updatePlayerH7;
	document.getElementById("setPlayerH8").onclick = updatePlayerH8;
	document.getElementById("setPlayerH9").onclick = updatePlayerH9;
	
	// Color the background in pink to indicate that a value was changed
	// but not yet stored. When the reset button is clicked, change the
	// background to white.
	
	// ### G1 ###:
	document.getElementById("pl_num_G1").addEventListener("input", function(){
		document.getElementById("pl_num_G1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G1").addEventListener("input", function(){
		document.getElementById("pl_gname_G1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G1").addEventListener("input", function(){
		document.getElementById("pl_fname_G1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G1").addEventListener("input", function(){
		document.getElementById("pl_pos_G1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G1").addEventListener("input", function(){
		document.getElementById("pl_hits_G1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G1").addEventListener("input", function(){
		document.getElementById("pl_atbats_G1").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG1").addEventListener("input", function(){
		document.getElementById("pl_atbats_G1").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG1").addEventListener("click", function(){
		document.getElementById("pl_num_G1").style.backgroundColor = "white";
		document.getElementById("pl_gname_G1").style.backgroundColor = "white";
		document.getElementById("pl_fname_G1").style.backgroundColor = "white";
		document.getElementById("pl_pos_G1").style.backgroundColor = "white";
		document.getElementById("pl_hits_G1").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G1").style.backgroundColor = "white";
		webiopi().callMacro("update_player", ['G1',0,'','','',0,0]);
	});
	// ### G2 ###:
	document.getElementById("pl_num_G2").addEventListener("input", function(){
		document.getElementById("pl_num_G2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G2").addEventListener("input", function(){
		document.getElementById("pl_gname_G2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G2").addEventListener("input", function(){
		document.getElementById("pl_fname_G2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G2").addEventListener("input", function(){
		document.getElementById("pl_pos_G2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G2").addEventListener("input", function(){
		document.getElementById("pl_hits_G2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G2").addEventListener("input", function(){
		document.getElementById("pl_atbats_G2").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG2").addEventListener("input", function(){
		document.getElementById("pl_atbats_G2").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG2").addEventListener("click", function(){
		document.getElementById("pl_num_G2").style.backgroundColor = "white";
		document.getElementById("pl_gname_G2").style.backgroundColor = "white";
		document.getElementById("pl_fname_G2").style.backgroundColor = "white";
		document.getElementById("pl_pos_G2").style.backgroundColor = "white";
		document.getElementById("pl_hits_G2").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G2").style.backgroundColor = "white";
	});
	// ### G3 ###:
	document.getElementById("pl_num_G3").addEventListener("input", function(){
		document.getElementById("pl_num_G3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G3").addEventListener("input", function(){
		document.getElementById("pl_gname_G3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G3").addEventListener("input", function(){
		document.getElementById("pl_fname_G3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G3").addEventListener("input", function(){
		document.getElementById("pl_pos_G3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G3").addEventListener("input", function(){
		document.getElementById("pl_hits_G3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G3").addEventListener("input", function(){
		document.getElementById("pl_atbats_G3").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG3").addEventListener("input", function(){
		document.getElementById("pl_atbats_G3").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG3").addEventListener("click", function(){
		document.getElementById("pl_num_G3").style.backgroundColor = "white";
		document.getElementById("pl_gname_G3").style.backgroundColor = "white";
		document.getElementById("pl_fname_G3").style.backgroundColor = "white";
		document.getElementById("pl_pos_G3").style.backgroundColor = "white";
		document.getElementById("pl_hits_G3").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G3").style.backgroundColor = "white";
	});
	// ### G4 ###:
	document.getElementById("pl_num_G4").addEventListener("input", function(){
		document.getElementById("pl_num_G4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G4").addEventListener("input", function(){
		document.getElementById("pl_gname_G4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G4").addEventListener("input", function(){
		document.getElementById("pl_fname_G4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G4").addEventListener("input", function(){
		document.getElementById("pl_pos_G4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G4").addEventListener("input", function(){
		document.getElementById("pl_hits_G4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G4").addEventListener("input", function(){
		document.getElementById("pl_atbats_G4").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG4").addEventListener("input", function(){
		document.getElementById("pl_atbats_G4").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG4").addEventListener("click", function(){
		document.getElementById("pl_num_G4").style.backgroundColor = "white";
		document.getElementById("pl_gname_G4").style.backgroundColor = "white";
		document.getElementById("pl_fname_G4").style.backgroundColor = "white";
		document.getElementById("pl_pos_G4").style.backgroundColor = "white";
		document.getElementById("pl_hits_G4").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G4").style.backgroundColor = "white";
	});
	// ### G5 ###:
	document.getElementById("pl_num_G5").addEventListener("input", function(){
		document.getElementById("pl_num_G5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G5").addEventListener("input", function(){
		document.getElementById("pl_gname_G5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G5").addEventListener("input", function(){
		document.getElementById("pl_fname_G5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G5").addEventListener("input", function(){
		document.getElementById("pl_pos_G5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G5").addEventListener("input", function(){
		document.getElementById("pl_hits_G5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G5").addEventListener("input", function(){
		document.getElementById("pl_atbats_G5").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG5").addEventListener("input", function(){
		document.getElementById("pl_atbats_G5").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG5").addEventListener("click", function(){
		document.getElementById("pl_num_G5").style.backgroundColor = "white";
		document.getElementById("pl_gname_G5").style.backgroundColor = "white";
		document.getElementById("pl_fname_G5").style.backgroundColor = "white";
		document.getElementById("pl_pos_G5").style.backgroundColor = "white";
		document.getElementById("pl_hits_G5").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G5").style.backgroundColor = "white";
	});
	// ### G6 ###:
	document.getElementById("pl_num_G6").addEventListener("input", function(){
		document.getElementById("pl_num_G6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G6").addEventListener("input", function(){
		document.getElementById("pl_gname_G6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G6").addEventListener("input", function(){
		document.getElementById("pl_fname_G6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G6").addEventListener("input", function(){
		document.getElementById("pl_pos_G6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G6").addEventListener("input", function(){
		document.getElementById("pl_hits_G6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G6").addEventListener("input", function(){
		document.getElementById("pl_atbats_G6").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG6").addEventListener("input", function(){
		document.getElementById("pl_atbats_G6").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG6").addEventListener("click", function(){
		document.getElementById("pl_num_G6").style.backgroundColor = "white";
		document.getElementById("pl_gname_G6").style.backgroundColor = "white";
		document.getElementById("pl_fname_G6").style.backgroundColor = "white";
		document.getElementById("pl_pos_G6").style.backgroundColor = "white";
		document.getElementById("pl_hits_G6").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G6").style.backgroundColor = "white";
	});
	// ### G7 ###:
	document.getElementById("pl_num_G7").addEventListener("input", function(){
		document.getElementById("pl_num_G7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G7").addEventListener("input", function(){
		document.getElementById("pl_gname_G7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G7").addEventListener("input", function(){
		document.getElementById("pl_fname_G7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G7").addEventListener("input", function(){
		document.getElementById("pl_pos_G7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G7").addEventListener("input", function(){
		document.getElementById("pl_hits_G7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G7").addEventListener("input", function(){
		document.getElementById("pl_atbats_G7").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG7").addEventListener("input", function(){
		document.getElementById("pl_atbats_G7").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG7").addEventListener("click", function(){
		document.getElementById("pl_num_G7").style.backgroundColor = "white";
		document.getElementById("pl_gname_G7").style.backgroundColor = "white";
		document.getElementById("pl_fname_G7").style.backgroundColor = "white";
		document.getElementById("pl_pos_G7").style.backgroundColor = "white";
		document.getElementById("pl_hits_G7").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G7").style.backgroundColor = "white";
	});
	// ### G8 ###:
	document.getElementById("pl_num_G8").addEventListener("input", function(){
		document.getElementById("pl_num_G8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G8").addEventListener("input", function(){
		document.getElementById("pl_gname_G8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G8").addEventListener("input", function(){
		document.getElementById("pl_fname_G8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G8").addEventListener("input", function(){
		document.getElementById("pl_pos_G8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G8").addEventListener("input", function(){
		document.getElementById("pl_hits_G8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G8").addEventListener("input", function(){
		document.getElementById("pl_atbats_G8").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG8").addEventListener("input", function(){
		document.getElementById("pl_atbats_G8").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG8").addEventListener("click", function(){
		document.getElementById("pl_num_G8").style.backgroundColor = "white";
		document.getElementById("pl_gname_G8").style.backgroundColor = "white";
		document.getElementById("pl_fname_G8").style.backgroundColor = "white";
		document.getElementById("pl_pos_G8").style.backgroundColor = "white";
		document.getElementById("pl_hits_G8").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G8").style.backgroundColor = "white";
	});
	// ### G9 ###:
	document.getElementById("pl_num_G9").addEventListener("input", function(){
		document.getElementById("pl_num_G9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_G9").addEventListener("input", function(){
		document.getElementById("pl_gname_G9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_G9").addEventListener("input", function(){
		document.getElementById("pl_fname_G9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_G9").addEventListener("input", function(){
		document.getElementById("pl_pos_G9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_G9").addEventListener("input", function(){
		document.getElementById("pl_hits_G9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_G9").addEventListener("input", function(){
		document.getElementById("pl_atbats_G9").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerG9").addEventListener("input", function(){
		document.getElementById("pl_atbats_G9").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerG9").addEventListener("click", function(){
		document.getElementById("pl_num_G9").style.backgroundColor = "white";
		document.getElementById("pl_gname_G9").style.backgroundColor = "white";
		document.getElementById("pl_fname_G9").style.backgroundColor = "white";
		document.getElementById("pl_pos_G9").style.backgroundColor = "white";
		document.getElementById("pl_hits_G9").style.backgroundColor = "white";
		document.getElementById("pl_atbats_G9").style.backgroundColor = "white";
	});
	// ### H1 ###:
	document.getElementById("pl_num_H1").addEventListener("input", function(){
		document.getElementById("pl_num_H1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H1").addEventListener("input", function(){
		document.getElementById("pl_gname_H1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H1").addEventListener("input", function(){
		document.getElementById("pl_fname_H1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H1").addEventListener("input", function(){
		document.getElementById("pl_pos_H1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H1").addEventListener("input", function(){
		document.getElementById("pl_hits_H1").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H1").addEventListener("input", function(){
		document.getElementById("pl_atbats_H1").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH1").addEventListener("input", function(){
		document.getElementById("pl_atbats_H1").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH1").addEventListener("click", function(){
		document.getElementById("pl_num_H1").style.backgroundColor = "white";
		document.getElementById("pl_gname_H1").style.backgroundColor = "white";
		document.getElementById("pl_fname_H1").style.backgroundColor = "white";
		document.getElementById("pl_pos_H1").style.backgroundColor = "white";
		document.getElementById("pl_hits_H1").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H1").style.backgroundColor = "white";
	});
	// ### H2 ###:
	document.getElementById("pl_num_H2").addEventListener("input", function(){
		document.getElementById("pl_num_H2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H2").addEventListener("input", function(){
		document.getElementById("pl_gname_H2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H2").addEventListener("input", function(){
		document.getElementById("pl_fname_H2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H2").addEventListener("input", function(){
		document.getElementById("pl_pos_H2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H2").addEventListener("input", function(){
		document.getElementById("pl_hits_H2").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H2").addEventListener("input", function(){
		document.getElementById("pl_atbats_H2").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH2").addEventListener("input", function(){
		document.getElementById("pl_atbats_H2").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH2").addEventListener("click", function(){
		document.getElementById("pl_num_H2").style.backgroundColor = "white";
		document.getElementById("pl_gname_H2").style.backgroundColor = "white";
		document.getElementById("pl_fname_H2").style.backgroundColor = "white";
		document.getElementById("pl_pos_H2").style.backgroundColor = "white";
		document.getElementById("pl_hits_H2").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H2").style.backgroundColor = "white";
	});
	// ### H3 ###:
	document.getElementById("pl_num_H3").addEventListener("input", function(){
		document.getElementById("pl_num_H3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H3").addEventListener("input", function(){
		document.getElementById("pl_gname_H3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H3").addEventListener("input", function(){
		document.getElementById("pl_fname_H3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H3").addEventListener("input", function(){
		document.getElementById("pl_pos_H3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H3").addEventListener("input", function(){
		document.getElementById("pl_hits_H3").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H3").addEventListener("input", function(){
		document.getElementById("pl_atbats_H3").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH3").addEventListener("input", function(){
		document.getElementById("pl_atbats_H3").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH3").addEventListener("click", function(){
		document.getElementById("pl_num_H3").style.backgroundColor = "white";
		document.getElementById("pl_gname_H3").style.backgroundColor = "white";
		document.getElementById("pl_fname_H3").style.backgroundColor = "white";
		document.getElementById("pl_pos_H3").style.backgroundColor = "white";
		document.getElementById("pl_hits_H3").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H3").style.backgroundColor = "white";
	});
	// ### H4 ###:
	document.getElementById("pl_num_H4").addEventListener("input", function(){
		document.getElementById("pl_num_H4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H4").addEventListener("input", function(){
		document.getElementById("pl_gname_H4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H4").addEventListener("input", function(){
		document.getElementById("pl_fname_H4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H4").addEventListener("input", function(){
		document.getElementById("pl_pos_H4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H4").addEventListener("input", function(){
		document.getElementById("pl_hits_H4").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H4").addEventListener("input", function(){
		document.getElementById("pl_atbats_H4").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH4").addEventListener("input", function(){
		document.getElementById("pl_atbats_H4").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH4").addEventListener("click", function(){
		document.getElementById("pl_num_H4").style.backgroundColor = "white";
		document.getElementById("pl_gname_H4").style.backgroundColor = "white";
		document.getElementById("pl_fname_H4").style.backgroundColor = "white";
		document.getElementById("pl_pos_H4").style.backgroundColor = "white";
		document.getElementById("pl_hits_H4").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H4").style.backgroundColor = "white";
	});
	// ### H5 ###:
	document.getElementById("pl_num_H5").addEventListener("input", function(){
		document.getElementById("pl_num_H5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H5").addEventListener("input", function(){
		document.getElementById("pl_gname_H5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H5").addEventListener("input", function(){
		document.getElementById("pl_fname_H5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H5").addEventListener("input", function(){
		document.getElementById("pl_pos_H5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H5").addEventListener("input", function(){
		document.getElementById("pl_hits_H5").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H5").addEventListener("input", function(){
		document.getElementById("pl_atbats_H5").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH5").addEventListener("input", function(){
		document.getElementById("pl_atbats_H5").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH5").addEventListener("click", function(){
		document.getElementById("pl_num_H5").style.backgroundColor = "white";
		document.getElementById("pl_gname_H5").style.backgroundColor = "white";
		document.getElementById("pl_fname_H5").style.backgroundColor = "white";
		document.getElementById("pl_pos_H5").style.backgroundColor = "white";
		document.getElementById("pl_hits_H5").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H5").style.backgroundColor = "white";
	});
	// ### H6 ###:
	document.getElementById("pl_num_H6").addEventListener("input", function(){
		document.getElementById("pl_num_H6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H6").addEventListener("input", function(){
		document.getElementById("pl_gname_H6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H6").addEventListener("input", function(){
		document.getElementById("pl_fname_H6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H6").addEventListener("input", function(){
		document.getElementById("pl_pos_H6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H6").addEventListener("input", function(){
		document.getElementById("pl_hits_H6").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H6").addEventListener("input", function(){
		document.getElementById("pl_atbats_H6").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH6").addEventListener("input", function(){
		document.getElementById("pl_atbats_H6").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH6").addEventListener("click", function(){
		document.getElementById("pl_num_H6").style.backgroundColor = "white";
		document.getElementById("pl_gname_H6").style.backgroundColor = "white";
		document.getElementById("pl_fname_H6").style.backgroundColor = "white";
		document.getElementById("pl_pos_H6").style.backgroundColor = "white";
		document.getElementById("pl_hits_H6").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H6").style.backgroundColor = "white";
	});
	// ### H7 ###:
	document.getElementById("pl_num_H7").addEventListener("input", function(){
		document.getElementById("pl_num_H7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H7").addEventListener("input", function(){
		document.getElementById("pl_gname_H7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H7").addEventListener("input", function(){
		document.getElementById("pl_fname_H7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H7").addEventListener("input", function(){
		document.getElementById("pl_pos_H7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H7").addEventListener("input", function(){
		document.getElementById("pl_hits_H7").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H7").addEventListener("input", function(){
		document.getElementById("pl_atbats_H7").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH7").addEventListener("input", function(){
		document.getElementById("pl_atbats_H7").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH7").addEventListener("click", function(){
		document.getElementById("pl_num_H7").style.backgroundColor = "white";
		document.getElementById("pl_gname_H7").style.backgroundColor = "white";
		document.getElementById("pl_fname_H7").style.backgroundColor = "white";
		document.getElementById("pl_pos_H7").style.backgroundColor = "white";
		document.getElementById("pl_hits_H7").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H7").style.backgroundColor = "white";
	});
	// ### H8 ###:
	document.getElementById("pl_num_H8").addEventListener("input", function(){
		document.getElementById("pl_num_H8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H8").addEventListener("input", function(){
		document.getElementById("pl_gname_H8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H8").addEventListener("input", function(){
		document.getElementById("pl_fname_H8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H8").addEventListener("input", function(){
		document.getElementById("pl_pos_H8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H8").addEventListener("input", function(){
		document.getElementById("pl_hits_H8").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H8").addEventListener("input", function(){
		document.getElementById("pl_atbats_H8").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH8").addEventListener("input", function(){
		document.getElementById("pl_atbats_H8").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH8").addEventListener("click", function(){
		document.getElementById("pl_num_H8").style.backgroundColor = "white";
		document.getElementById("pl_gname_H8").style.backgroundColor = "white";
		document.getElementById("pl_fname_H8").style.backgroundColor = "white";
		document.getElementById("pl_pos_H8").style.backgroundColor = "white";
		document.getElementById("pl_hits_H8").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H8").style.backgroundColor = "white";
	});
	// ### H9 ###:
	document.getElementById("pl_num_H9").addEventListener("input", function(){
		document.getElementById("pl_num_H9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_gname_H9").addEventListener("input", function(){
		document.getElementById("pl_gname_H9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_fname_H9").addEventListener("input", function(){
		document.getElementById("pl_fname_H9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_pos_H9").addEventListener("input", function(){
		document.getElementById("pl_pos_H9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_hits_H9").addEventListener("input", function(){
		document.getElementById("pl_hits_H9").style.backgroundColor = "pink";
	});
	document.getElementById("pl_atbats_H9").addEventListener("input", function(){
		document.getElementById("pl_atbats_H9").style.backgroundColor = "pink";
	});
	document.getElementById("setPlayerH9").addEventListener("input", function(){
		document.getElementById("pl_atbats_H9").style.backgroundColor = "pink";
	});
	document.getElementById("resetPlayerH9").addEventListener("click", function(){
		document.getElementById("pl_num_H9").style.backgroundColor = "white";
		document.getElementById("pl_gname_H9").style.backgroundColor = "white";
		document.getElementById("pl_fname_H9").style.backgroundColor = "white";
		document.getElementById("pl_pos_H9").style.backgroundColor = "white";
		document.getElementById("pl_hits_H9").style.backgroundColor = "white";
		document.getElementById("pl_atbats_H9").style.backgroundColor = "white";
	});
	
	// Save entered data so they can be restored if the user refreshes
	// ### G1 ###
	var saved_pl_num_G1 = sessionStorage.getItem('pl_num_G1');
	if (saved_pl_num_G1 !== null) $('#pl_num_G1').val(saved_pl_num_G1);
	var saved_pl_gname_G1 = sessionStorage.getItem('pl_gname_G1');
	if (saved_pl_gname_G1 !== null) $('#pl_gname_G1').val(saved_pl_gname_G1);
	var saved_pl_fname_G1 = sessionStorage.getItem('pl_fname_G1');
	if (saved_pl_fname_G1 !== null) $('#pl_fname_G1').val(saved_pl_fname_G1);
	var saved_pl_pos_G1 = sessionStorage.getItem('pl_pos_G1');
	if (saved_pl_pos_G1 !== null) $('#pl_pos_G1').val(saved_pl_pos_G1);
	var saved_pl_hits_G1 = sessionStorage.getItem('pl_hits_G1');
	if (saved_pl_hits_G1 !== null) $('#pl_hits_G1').val(saved_pl_hits_G1);
	var saved_pl_atbats_G1 = sessionStorage.getItem('pl_atbats_G1');
	if (saved_pl_atbats_G1 !== null) $('#pl_atbats_G1').val(saved_pl_atbats_G1);
	
	// ### G2 ###
	var saved_pl_num_G2 = sessionStorage.getItem('pl_num_G2');
	if (saved_pl_num_G2 !== null) $('#pl_num_G2').val(saved_pl_num_G2);
	var saved_pl_gname_G2 = sessionStorage.getItem('pl_gname_G2');
	if (saved_pl_gname_G2 !== null) $('#pl_gname_G2').val(saved_pl_gname_G2);
	var saved_pl_fname_G2 = sessionStorage.getItem('pl_fname_G2');
	if (saved_pl_fname_G2 !== null) $('#pl_fname_G2').val(saved_pl_fname_G2);
	var saved_pl_pos_G2 = sessionStorage.getItem('pl_pos_G2');
	if (saved_pl_pos_G2 !== null) $('#pl_pos_G2').val(saved_pl_pos_G2);
	var saved_pl_hits_G2 = sessionStorage.getItem('pl_hits_G2');
	if (saved_pl_hits_G2 !== null) $('#pl_hits_G2').val(saved_pl_hits_G2);
	var saved_pl_atbats_G2 = sessionStorage.getItem('pl_atbats_G2');
	if (saved_pl_atbats_G2 !== null) $('#pl_atbats_G2').val(saved_pl_atbats_G2);
	
	// ### G3 ###
	var saved_pl_num_G3 = sessionStorage.getItem('pl_num_G3');
	if (saved_pl_num_G3 !== null) $('#pl_num_G3').val(saved_pl_num_G3);
	var saved_pl_gname_G3 = sessionStorage.getItem('pl_gname_G3');
	if (saved_pl_gname_G3 !== null) $('#pl_gname_G3').val(saved_pl_gname_G3);
	var saved_pl_fname_G3 = sessionStorage.getItem('pl_fname_G3');
	if (saved_pl_fname_G3 !== null) $('#pl_fname_G3').val(saved_pl_fname_G3);
	var saved_pl_pos_G3 = sessionStorage.getItem('pl_pos_G3');
	if (saved_pl_pos_G3 !== null) $('#pl_pos_G3').val(saved_pl_pos_G3);
	var saved_pl_hits_G3 = sessionStorage.getItem('pl_hits_G3');
	if (saved_pl_hits_G3 !== null) $('#pl_hits_G3').val(saved_pl_hits_G3);
	var saved_pl_atbats_G3 = sessionStorage.getItem('pl_atbats_G3');
	if (saved_pl_atbats_G3 !== null) $('#pl_atbats_G3').val(saved_pl_atbats_G3);
	
	// ### G4 ###
	var saved_pl_num_G4 = sessionStorage.getItem('pl_num_G4');
	if (saved_pl_num_G4 !== null) $('#pl_num_G4').val(saved_pl_num_G4);
	var saved_pl_gname_G4 = sessionStorage.getItem('pl_gname_G4');
	if (saved_pl_gname_G4 !== null) $('#pl_gname_G4').val(saved_pl_gname_G4);
	var saved_pl_fname_G4 = sessionStorage.getItem('pl_fname_G4');
	if (saved_pl_fname_G4 !== null) $('#pl_fname_G4').val(saved_pl_fname_G4);
	var saved_pl_pos_G4 = sessionStorage.getItem('pl_pos_G4');
	if (saved_pl_pos_G4 !== null) $('#pl_pos_G4').val(saved_pl_pos_G4);
	var saved_pl_hits_G4 = sessionStorage.getItem('pl_hits_G4');
	if (saved_pl_hits_G4 !== null) $('#pl_hits_G4').val(saved_pl_hits_G4);
	var saved_pl_atbats_G4 = sessionStorage.getItem('pl_atbats_G4');
	if (saved_pl_atbats_G4 !== null) $('#pl_atbats_G4').val(saved_pl_atbats_G4);
	
	// ### G5 ###
	var saved_pl_num_G5 = sessionStorage.getItem('pl_num_G5');
	if (saved_pl_num_G5 !== null) $('#pl_num_G5').val(saved_pl_num_G5);
	var saved_pl_gname_G5 = sessionStorage.getItem('pl_gname_G5');
	if (saved_pl_gname_G5 !== null) $('#pl_gname_G5').val(saved_pl_gname_G5);
	var saved_pl_fname_G5 = sessionStorage.getItem('pl_fname_G5');
	if (saved_pl_fname_G5 !== null) $('#pl_fname_G5').val(saved_pl_fname_G5);
	var saved_pl_pos_G5 = sessionStorage.getItem('pl_pos_G5');
	if (saved_pl_pos_G5 !== null) $('#pl_pos_G5').val(saved_pl_pos_G5);
	var saved_pl_hits_G5 = sessionStorage.getItem('pl_hits_G5');
	if (saved_pl_hits_G5 !== null) $('#pl_hits_G5').val(saved_pl_hits_G5);
	var saved_pl_atbats_G5 = sessionStorage.getItem('pl_atbats_G5');
	if (saved_pl_atbats_G5 !== null) $('#pl_atbats_G5').val(saved_pl_atbats_G5);
	
	// ### G6 ###
	var saved_pl_num_G6 = sessionStorage.getItem('pl_num_G6');
	if (saved_pl_num_G6 !== null) $('#pl_num_G6').val(saved_pl_num_G6);
	var saved_pl_gname_G6 = sessionStorage.getItem('pl_gname_G6');
	if (saved_pl_gname_G6 !== null) $('#pl_gname_G6').val(saved_pl_gname_G6);
	var saved_pl_fname_G6 = sessionStorage.getItem('pl_fname_G6');
	if (saved_pl_fname_G6 !== null) $('#pl_fname_G6').val(saved_pl_fname_G6);
	var saved_pl_pos_G6 = sessionStorage.getItem('pl_pos_G6');
	if (saved_pl_pos_G6 !== null) $('#pl_pos_G6').val(saved_pl_pos_G6);
	var saved_pl_hits_G6 = sessionStorage.getItem('pl_hits_G6');
	if (saved_pl_hits_G6 !== null) $('#pl_hits_G6').val(saved_pl_hits_G6);
	var saved_pl_atbats_G6 = sessionStorage.getItem('pl_atbats_G6');
	if (saved_pl_atbats_G6 !== null) $('#pl_atbats_G6').val(saved_pl_atbats_G6);
	
	// ### G7 ###
	var saved_pl_num_G7 = sessionStorage.getItem('pl_num_G7');
	if (saved_pl_num_G7 !== null) $('#pl_num_G7').val(saved_pl_num_G7);
	var saved_pl_gname_G7 = sessionStorage.getItem('pl_gname_G7');
	if (saved_pl_gname_G7 !== null) $('#pl_gname_G7').val(saved_pl_gname_G7);
	var saved_pl_fname_G7 = sessionStorage.getItem('pl_fname_G7');
	if (saved_pl_fname_G7 !== null) $('#pl_fname_G7').val(saved_pl_fname_G7);
	var saved_pl_pos_G7 = sessionStorage.getItem('pl_pos_G7');
	if (saved_pl_pos_G7 !== null) $('#pl_pos_G7').val(saved_pl_pos_G7);
	var saved_pl_hits_G7 = sessionStorage.getItem('pl_hits_G7');
	if (saved_pl_hits_G7 !== null) $('#pl_hits_G7').val(saved_pl_hits_G7);
	var saved_pl_atbats_G7 = sessionStorage.getItem('pl_atbats_G7');
	if (saved_pl_atbats_G7 !== null) $('#pl_atbats_G7').val(saved_pl_atbats_G7);
	
	// ### G8 ###
	var saved_pl_num_G8 = sessionStorage.getItem('pl_num_G8');
	if (saved_pl_num_G8 !== null) $('#pl_num_G8').val(saved_pl_num_G8);
	var saved_pl_gname_G8 = sessionStorage.getItem('pl_gname_G8');
	if (saved_pl_gname_G8 !== null) $('#pl_gname_G8').val(saved_pl_gname_G8);
	var saved_pl_fname_G8 = sessionStorage.getItem('pl_fname_G8');
	if (saved_pl_fname_G8 !== null) $('#pl_fname_G8').val(saved_pl_fname_G8);
	var saved_pl_pos_G8 = sessionStorage.getItem('pl_pos_G8');
	if (saved_pl_pos_G8 !== null) $('#pl_pos_G8').val(saved_pl_pos_G8);
	var saved_pl_hits_G8 = sessionStorage.getItem('pl_hits_G8');
	if (saved_pl_hits_G8 !== null) $('#pl_hits_G8').val(saved_pl_hits_G8);
	var saved_pl_atbats_G8 = sessionStorage.getItem('pl_atbats_G8');
	if (saved_pl_atbats_G8 !== null) $('#pl_atbats_G8').val(saved_pl_atbats_G8);
	
	// ### G9 ###
	var saved_pl_num_G9 = sessionStorage.getItem('pl_num_G9');
	if (saved_pl_num_G9 !== null) $('#pl_num_G9').val(saved_pl_num_G9);
	var saved_pl_gname_G9 = sessionStorage.getItem('pl_gname_G9');
	if (saved_pl_gname_G9 !== null) $('#pl_gname_G9').val(saved_pl_gname_G9);
	var saved_pl_fname_G9 = sessionStorage.getItem('pl_fname_G9');
	if (saved_pl_fname_G9 !== null) $('#pl_fname_G9').val(saved_pl_fname_G9);
	var saved_pl_pos_G9 = sessionStorage.getItem('pl_pos_G9');
	if (saved_pl_pos_G9 !== null) $('#pl_pos_G9').val(saved_pl_pos_G9);
	var saved_pl_hits_G9 = sessionStorage.getItem('pl_hits_G9');
	if (saved_pl_hits_G9 !== null) $('#pl_hits_G9').val(saved_pl_hits_G9);
	var saved_pl_atbats_G9 = sessionStorage.getItem('pl_atbats_G9');
	if (saved_pl_atbats_G9 !== null) $('#pl_atbats_G9').val(saved_pl_atbats_G9);

	// ### H1 ###
	var saved_pl_num_H1 = sessionStorage.getItem('pl_num_H1');
	if (saved_pl_num_H1 !== null) $('#pl_num_H1').val(saved_pl_num_H1);
	var saved_pl_gname_H1 = sessionStorage.getItem('pl_gname_H1');
	if (saved_pl_gname_H1 !== null) $('#pl_gname_H1').val(saved_pl_gname_H1);
	var saved_pl_fname_H1 = sessionStorage.getItem('pl_fname_H1');
	if (saved_pl_fname_H1 !== null) $('#pl_fname_H1').val(saved_pl_fname_H1);
	var saved_pl_pos_H1 = sessionStorage.getItem('pl_pos_H1');
	if (saved_pl_pos_H1 !== null) $('#pl_pos_H1').val(saved_pl_pos_H1);
	var saved_pl_hits_H1 = sessionStorage.getItem('pl_hits_H1');
	if (saved_pl_hits_H1 !== null) $('#pl_hits_H1').val(saved_pl_hits_H1);
	var saved_pl_atbats_H1 = sessionStorage.getItem('pl_atbats_H1');
	if (saved_pl_atbats_H1 !== null) $('#pl_atbats_H1').val(saved_pl_atbats_H1);
	
	// ### H2 ###
	var saved_pl_num_H2 = sessionStorage.getItem('pl_num_H2');
	if (saved_pl_num_H2 !== null) $('#pl_num_H2').val(saved_pl_num_H2);
	var saved_pl_gname_H2 = sessionStorage.getItem('pl_gname_H2');
	if (saved_pl_gname_H2 !== null) $('#pl_gname_H2').val(saved_pl_gname_H2);
	var saved_pl_fname_H2 = sessionStorage.getItem('pl_fname_H2');
	if (saved_pl_fname_H2 !== null) $('#pl_fname_H2').val(saved_pl_fname_H2);
	var saved_pl_pos_H2 = sessionStorage.getItem('pl_pos_H2');
	if (saved_pl_pos_H2 !== null) $('#pl_pos_H2').val(saved_pl_pos_H2);
	var saved_pl_hits_H2 = sessionStorage.getItem('pl_hits_H2');
	if (saved_pl_hits_H2 !== null) $('#pl_hits_H2').val(saved_pl_hits_H2);
	var saved_pl_atbats_H2 = sessionStorage.getItem('pl_atbats_H2');
	if (saved_pl_atbats_H2 !== null) $('#pl_atbats_H2').val(saved_pl_atbats_H2);
	
	// ### H3 ###
	var saved_pl_num_H3 = sessionStorage.getItem('pl_num_H3');
	if (saved_pl_num_H3 !== null) $('#pl_num_H3').val(saved_pl_num_H3);
	var saved_pl_gname_H3 = sessionStorage.getItem('pl_gname_H3');
	if (saved_pl_gname_H3 !== null) $('#pl_gname_H3').val(saved_pl_gname_H3);
	var saved_pl_fname_H3 = sessionStorage.getItem('pl_fname_H3');
	if (saved_pl_fname_H3 !== null) $('#pl_fname_H3').val(saved_pl_fname_H3);
	var saved_pl_pos_H3 = sessionStorage.getItem('pl_pos_H3');
	if (saved_pl_pos_H3 !== null) $('#pl_pos_H3').val(saved_pl_pos_H3);
	var saved_pl_hits_H3 = sessionStorage.getItem('pl_hits_H3');
	if (saved_pl_hits_H3 !== null) $('#pl_hits_H3').val(saved_pl_hits_H3);
	var saved_pl_atbats_H3 = sessionStorage.getItem('pl_atbats_H3');
	if (saved_pl_atbats_H3 !== null) $('#pl_atbats_H3').val(saved_pl_atbats_H3);
	
	// ### H4 ###
	var saved_pl_num_H4 = sessionStorage.getItem('pl_num_H4');
	if (saved_pl_num_H4 !== null) $('#pl_num_H4').val(saved_pl_num_H4);
	var saved_pl_gname_H4 = sessionStorage.getItem('pl_gname_H4');
	if (saved_pl_gname_H4 !== null) $('#pl_gname_H4').val(saved_pl_gname_H4);
	var saved_pl_fname_H4 = sessionStorage.getItem('pl_fname_H4');
	if (saved_pl_fname_H4 !== null) $('#pl_fname_H4').val(saved_pl_fname_H4);
	var saved_pl_pos_H4 = sessionStorage.getItem('pl_pos_H4');
	if (saved_pl_pos_H4 !== null) $('#pl_pos_H4').val(saved_pl_pos_H4);
	var saved_pl_hits_H4 = sessionStorage.getItem('pl_hits_H4');
	if (saved_pl_hits_H4 !== null) $('#pl_hits_H4').val(saved_pl_hits_H4);
	var saved_pl_atbats_H4 = sessionStorage.getItem('pl_atbats_H4');
	if (saved_pl_atbats_H4 !== null) $('#pl_atbats_H4').val(saved_pl_atbats_H4);
	
	// ### H5 ###
	var saved_pl_num_H5 = sessionStorage.getItem('pl_num_H5');
	if (saved_pl_num_H5 !== null) $('#pl_num_H5').val(saved_pl_num_H5);
	var saved_pl_gname_H5 = sessionStorage.getItem('pl_gname_H5');
	if (saved_pl_gname_H5 !== null) $('#pl_gname_H5').val(saved_pl_gname_H5);
	var saved_pl_fname_H5 = sessionStorage.getItem('pl_fname_H5');
	if (saved_pl_fname_H5 !== null) $('#pl_fname_H5').val(saved_pl_fname_H5);
	var saved_pl_pos_H5 = sessionStorage.getItem('pl_pos_H5');
	if (saved_pl_pos_H5 !== null) $('#pl_pos_H5').val(saved_pl_pos_H5);
	var saved_pl_hits_H5 = sessionStorage.getItem('pl_hits_H5');
	if (saved_pl_hits_H5 !== null) $('#pl_hits_H5').val(saved_pl_hits_H5);
	var saved_pl_atbats_H5 = sessionStorage.getItem('pl_atbats_H5');
	if (saved_pl_atbats_H5 !== null) $('#pl_atbats_H5').val(saved_pl_atbats_H5);
	
	// ### H6 ###
	var saved_pl_num_H6 = sessionStorage.getItem('pl_num_H6');
	if (saved_pl_num_H6 !== null) $('#pl_num_H6').val(saved_pl_num_H6);
	var saved_pl_gname_H6 = sessionStorage.getItem('pl_gname_H6');
	if (saved_pl_gname_H6 !== null) $('#pl_gname_H6').val(saved_pl_gname_H6);
	var saved_pl_fname_H6 = sessionStorage.getItem('pl_fname_H6');
	if (saved_pl_fname_H6 !== null) $('#pl_fname_H6').val(saved_pl_fname_H6);
	var saved_pl_pos_H6 = sessionStorage.getItem('pl_pos_H6');
	if (saved_pl_pos_H6 !== null) $('#pl_pos_H6').val(saved_pl_pos_H6);
	var saved_pl_hits_H6 = sessionStorage.getItem('pl_hits_H6');
	if (saved_pl_hits_H6 !== null) $('#pl_hits_H6').val(saved_pl_hits_H6);
	var saved_pl_atbats_H6 = sessionStorage.getItem('pl_atbats_H6');
	if (saved_pl_atbats_H6 !== null) $('#pl_atbats_H6').val(saved_pl_atbats_H6);
	
	// ### H7 ###
	var saved_pl_num_H7 = sessionStorage.getItem('pl_num_H7');
	if (saved_pl_num_H7 !== null) $('#pl_num_H7').val(saved_pl_num_H7);
	var saved_pl_gname_H7 = sessionStorage.getItem('pl_gname_H7');
	if (saved_pl_gname_H7 !== null) $('#pl_gname_H7').val(saved_pl_gname_H7);
	var saved_pl_fname_H7 = sessionStorage.getItem('pl_fname_H7');
	if (saved_pl_fname_H7 !== null) $('#pl_fname_H7').val(saved_pl_fname_H7);
	var saved_pl_pos_H7 = sessionStorage.getItem('pl_pos_H7');
	if (saved_pl_pos_H7 !== null) $('#pl_pos_H7').val(saved_pl_pos_H7);
	var saved_pl_hits_H7 = sessionStorage.getItem('pl_hits_H7');
	if (saved_pl_hits_H7 !== null) $('#pl_hits_H7').val(saved_pl_hits_H7);
	var saved_pl_atbats_H7 = sessionStorage.getItem('pl_atbats_H7');
	if (saved_pl_atbats_H7 !== null) $('#pl_atbats_H7').val(saved_pl_atbats_H7);
	
	// ### H8 ###
	var saved_pl_num_H8 = sessionStorage.getItem('pl_num_H8');
	if (saved_pl_num_H8 !== null) $('#pl_num_H8').val(saved_pl_num_H8);
	var saved_pl_gname_H8 = sessionStorage.getItem('pl_gname_H8');
	if (saved_pl_gname_H8 !== null) $('#pl_gname_H8').val(saved_pl_gname_H8);
	var saved_pl_fname_H8 = sessionStorage.getItem('pl_fname_H8');
	if (saved_pl_fname_H8 !== null) $('#pl_fname_H8').val(saved_pl_fname_H8);
	var saved_pl_pos_H8 = sessionStorage.getItem('pl_pos_H8');
	if (saved_pl_pos_H8 !== null) $('#pl_pos_H8').val(saved_pl_pos_H8);
	var saved_pl_hits_H8 = sessionStorage.getItem('pl_hits_H8');
	if (saved_pl_hits_H8 !== null) $('#pl_hits_H8').val(saved_pl_hits_H8);
	var saved_pl_atbats_H8 = sessionStorage.getItem('pl_atbats_H8');
	if (saved_pl_atbats_H8 !== null) $('#pl_atbats_H8').val(saved_pl_atbats_H8);
	
	// ### H9 ###
	var saved_pl_num_H9 = sessionStorage.getItem('pl_num_H9');
	if (saved_pl_num_H9 !== null) $('#pl_num_H9').val(saved_pl_num_H9);
	var saved_pl_gname_H9 = sessionStorage.getItem('pl_gname_H9');
	if (saved_pl_gname_H9 !== null) $('#pl_gname_H9').val(saved_pl_gname_H9);
	var saved_pl_fname_H9 = sessionStorage.getItem('pl_fname_H9');
	if (saved_pl_fname_H9 !== null) $('#pl_fname_H9').val(saved_pl_fname_H9);
	var saved_pl_pos_H9 = sessionStorage.getItem('pl_pos_H9');
	if (saved_pl_pos_H9 !== null) $('#pl_pos_H9').val(saved_pl_pos_H9);
	var saved_pl_hits_H9 = sessionStorage.getItem('pl_hits_H9');
	if (saved_pl_hits_H9 !== null) $('#pl_hits_H9').val(saved_pl_hits_H9);
	var saved_pl_atbats_H9 = sessionStorage.getItem('pl_atbats_H9');
	if (saved_pl_atbats_H9 !== null) $('#pl_atbats_H9').val(saved_pl_atbats_H9);
};

window.onbeforeunload = function() {
	// Restore player data after a refresh
	// ### G1 ###
	sessionStorage.setItem("pl_num_G1", $('#pl_num_G1').val());
	sessionStorage.setItem("pl_gname_G1", $('#pl_gname_G1').val());
	sessionStorage.setItem("pl_fname_G1", $('#pl_fname_G1').val());
	sessionStorage.setItem("pl_pos_G1", $('#pl_pos_G1').val());
	sessionStorage.setItem("pl_hits_G1", $('#pl_hits_G1').val());
	sessionStorage.setItem("pl_atbats_G1", $('#pl_atbats_G1').val());

	// ### G2 ###
	sessionStorage.setItem("pl_num_G2", $('#pl_num_G2').val());
	sessionStorage.setItem("pl_gname_G2", $('#pl_gname_G2').val());
	sessionStorage.setItem("pl_fname_G2", $('#pl_fname_G2').val());
	sessionStorage.setItem("pl_pos_G2", $('#pl_pos_G2').val());
	sessionStorage.setItem("pl_hits_G2", $('#pl_hits_G2').val());
	sessionStorage.setItem("pl_atbats_G2", $('#pl_atbats_G2').val());

	// ### G3 ###
	sessionStorage.setItem("pl_num_G3", $('#pl_num_G3').val());
	sessionStorage.setItem("pl_gname_G3", $('#pl_gname_G3').val());
	sessionStorage.setItem("pl_fname_G3", $('#pl_fname_G3').val());
	sessionStorage.setItem("pl_pos_G3", $('#pl_pos_G3').val());
	sessionStorage.setItem("pl_hits_G3", $('#pl_hits_G3').val());
	sessionStorage.setItem("pl_atbats_G3", $('#pl_atbats_G3').val());

	// ### G4 ###
	sessionStorage.setItem("pl_num_G4", $('#pl_num_G4').val());
	sessionStorage.setItem("pl_gname_G4", $('#pl_gname_G4').val());
	sessionStorage.setItem("pl_fname_G4", $('#pl_fname_G4').val());
	sessionStorage.setItem("pl_pos_G4", $('#pl_pos_G4').val());
	sessionStorage.setItem("pl_hits_G4", $('#pl_hits_G4').val());
	sessionStorage.setItem("pl_atbats_G4", $('#pl_atbats_G4').val());

	// ### G5 ###
	sessionStorage.setItem("pl_num_G5", $('#pl_num_G5').val());
	sessionStorage.setItem("pl_gname_G5", $('#pl_gname_G5').val());
	sessionStorage.setItem("pl_fname_G5", $('#pl_fname_G5').val());
	sessionStorage.setItem("pl_pos_G5", $('#pl_pos_G5').val());
	sessionStorage.setItem("pl_hits_G5", $('#pl_hits_G5').val());
	sessionStorage.setItem("pl_atbats_G5", $('#pl_atbats_G5').val());

	// ### G6 ###
	sessionStorage.setItem("pl_num_G6", $('#pl_num_G6').val());
	sessionStorage.setItem("pl_gname_G6", $('#pl_gname_G6').val());
	sessionStorage.setItem("pl_fname_G6", $('#pl_fname_G6').val());
	sessionStorage.setItem("pl_pos_G6", $('#pl_pos_G6').val());
	sessionStorage.setItem("pl_hits_G6", $('#pl_hits_G6').val());
	sessionStorage.setItem("pl_atbats_G6", $('#pl_atbats_G6').val());

	// ### G7 ###
	sessionStorage.setItem("pl_num_G7", $('#pl_num_G7').val());
	sessionStorage.setItem("pl_gname_G7", $('#pl_gname_G7').val());
	sessionStorage.setItem("pl_fname_G7", $('#pl_fname_G7').val());
	sessionStorage.setItem("pl_pos_G7", $('#pl_pos_G7').val());
	sessionStorage.setItem("pl_hits_G7", $('#pl_hits_G7').val());
	sessionStorage.setItem("pl_atbats_G7", $('#pl_atbats_G7').val());

	// ### G8 ###
	sessionStorage.setItem("pl_num_G8", $('#pl_num_G8').val());
	sessionStorage.setItem("pl_gname_G8", $('#pl_gname_G8').val());
	sessionStorage.setItem("pl_fname_G8", $('#pl_fname_G8').val());
	sessionStorage.setItem("pl_pos_G8", $('#pl_pos_G8').val());
	sessionStorage.setItem("pl_hits_G8", $('#pl_hits_G8').val());
	sessionStorage.setItem("pl_atbats_G8", $('#pl_atbats_G8').val());

	// ### G9 ###
	sessionStorage.setItem("pl_num_G9", $('#pl_num_G9').val());
	sessionStorage.setItem("pl_gname_G9", $('#pl_gname_G9').val());
	sessionStorage.setItem("pl_fname_G9", $('#pl_fname_G9').val());
	sessionStorage.setItem("pl_pos_G9", $('#pl_pos_G9').val());
	sessionStorage.setItem("pl_hits_G9", $('#pl_hits_G9').val());
	sessionStorage.setItem("pl_atbats_G9", $('#pl_atbats_G9').val());

	// ### H1 ###
	sessionStorage.setItem("pl_num_H1", $('#pl_num_H1').val());
	sessionStorage.setItem("pl_gname_H1", $('#pl_gname_H1').val());
	sessionStorage.setItem("pl_fname_H1", $('#pl_fname_H1').val());
	sessionStorage.setItem("pl_pos_H1", $('#pl_pos_H1').val());
	sessionStorage.setItem("pl_hits_H1", $('#pl_hits_H1').val());
	sessionStorage.setItem("pl_atbats_H1", $('#pl_atbats_H1').val());

	// ### H2 ###
	sessionStorage.setItem("pl_num_H2", $('#pl_num_H2').val());
	sessionStorage.setItem("pl_gname_H2", $('#pl_gname_H2').val());
	sessionStorage.setItem("pl_fname_H2", $('#pl_fname_H2').val());
	sessionStorage.setItem("pl_pos_H2", $('#pl_pos_H2').val());
	sessionStorage.setItem("pl_hits_H2", $('#pl_hits_H2').val());
	sessionStorage.setItem("pl_atbats_H2", $('#pl_atbats_H2').val());

	// ### H3 ###
	sessionStorage.setItem("pl_num_H3", $('#pl_num_H3').val());
	sessionStorage.setItem("pl_gname_H3", $('#pl_gname_H3').val());
	sessionStorage.setItem("pl_fname_H3", $('#pl_fname_H3').val());
	sessionStorage.setItem("pl_pos_H3", $('#pl_pos_H3').val());
	sessionStorage.setItem("pl_hits_H3", $('#pl_hits_H3').val());
	sessionStorage.setItem("pl_atbats_H3", $('#pl_atbats_H3').val());

	// ### H4 ###
	sessionStorage.setItem("pl_num_H4", $('#pl_num_H4').val());
	sessionStorage.setItem("pl_gname_H4", $('#pl_gname_H4').val());
	sessionStorage.setItem("pl_fname_H4", $('#pl_fname_H4').val());
	sessionStorage.setItem("pl_pos_H4", $('#pl_pos_H4').val());
	sessionStorage.setItem("pl_hits_H4", $('#pl_hits_H4').val());
	sessionStorage.setItem("pl_atbats_H4", $('#pl_atbats_H4').val());

	// ### H5 ###
	sessionStorage.setItem("pl_num_H5", $('#pl_num_H5').val());
	sessionStorage.setItem("pl_gname_H5", $('#pl_gname_H5').val());
	sessionStorage.setItem("pl_fname_H5", $('#pl_fname_H5').val());
	sessionStorage.setItem("pl_pos_H5", $('#pl_pos_H5').val());
	sessionStorage.setItem("pl_hits_H5", $('#pl_hits_H5').val());
	sessionStorage.setItem("pl_atbats_H5", $('#pl_atbats_H5').val());

	// ### H6 ###
	sessionStorage.setItem("pl_num_H6", $('#pl_num_H6').val());
	sessionStorage.setItem("pl_gname_H6", $('#pl_gname_H6').val());
	sessionStorage.setItem("pl_fname_H6", $('#pl_fname_H6').val());
	sessionStorage.setItem("pl_pos_H6", $('#pl_pos_H6').val());
	sessionStorage.setItem("pl_hits_H6", $('#pl_hits_H6').val());
	sessionStorage.setItem("pl_atbats_H6", $('#pl_atbats_H6').val());

	// ### H7 ###
	sessionStorage.setItem("pl_num_H7", $('#pl_num_H7').val());
	sessionStorage.setItem("pl_gname_H7", $('#pl_gname_H7').val());
	sessionStorage.setItem("pl_fname_H7", $('#pl_fname_H7').val());
	sessionStorage.setItem("pl_pos_H7", $('#pl_pos_H7').val());
	sessionStorage.setItem("pl_hits_H7", $('#pl_hits_H7').val());
	sessionStorage.setItem("pl_atbats_H7", $('#pl_atbats_H7').val());

	// ### H8 ###
	sessionStorage.setItem("pl_num_H8", $('#pl_num_H8').val());
	sessionStorage.setItem("pl_gname_H8", $('#pl_gname_H8').val());
	sessionStorage.setItem("pl_fname_H8", $('#pl_fname_H8').val());
	sessionStorage.setItem("pl_pos_H8", $('#pl_pos_H8').val());
	sessionStorage.setItem("pl_hits_H8", $('#pl_hits_H8').val());
	sessionStorage.setItem("pl_atbats_H8", $('#pl_atbats_H8').val());

	// ### H9 ###
	sessionStorage.setItem("pl_num_H9", $('#pl_num_H9').val());
	sessionStorage.setItem("pl_gname_H9", $('#pl_gname_H9').val());
	sessionStorage.setItem("pl_fname_H9", $('#pl_fname_H9').val());
	sessionStorage.setItem("pl_pos_H9", $('#pl_pos_H9').val());
	sessionStorage.setItem("pl_hits_H9", $('#pl_hits_H9').val());
	sessionStorage.setItem("pl_atbats_H9", $('#pl_atbats_H9').val());

};