# scoreboard.py - main script for the scoreboard control
#
#    Copyright (C) 2015-2017 Anders Lind, Erding Mallards e.V.
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Version 3, April 14, 2017

import webiopi
import sbvar
import sbfunc

# WebIoPi pre-defined functions
def setup():
    sbfunc.set_display_mode(3)

def loop():
    pass

def destroy():
    pass


# Macro functions called by the javascript
@webiopi.macro
def get_inning_label():
    label = sbfunc.get_inning_label()
    return label

@webiopi.macro
def update_inning_count(direction):
    sbfunc.update_inning_count(direction)
    return None

@webiopi.macro
def update_inning_runs(direction):
    sbfunc.update_inning_runs(sbvar.counter_INNING,direction)
    return None

@webiopi.macro
def update_hits_count(direction):
    if sbvar.counter_INNING != 0 and (sbvar.counter_INNING % 2) != 0:
        team = 'G'
        sbfunc.update_hits_count(team,direction,1)
    elif sbvar.counter_INNING != 0 and (sbvar.counter_INNING % 2) == 0:
        team = 'H'
        sbfunc.update_hits_count(team,direction,1)
    else:
        pass
    return None

@webiopi.macro
def update_error_count(direction):
    if sbvar.counter_INNING != 0 and (sbvar.counter_INNING % 2) != 0:
        team = 'HE'
        sbfunc.update_error_count(team,direction,1)
    elif sbvar.counter_INNING != 0 and (sbvar.counter_INNING % 2) == 0:
        team = 'GE'
        sbfunc.update_error_count(team,direction,1)
    else:
        pass

    return None

@webiopi.macro
def update_balls_count():
    sbfunc.update_balls_count()
    return None
@webiopi.macro

def update_strikes_count():
    sbfunc.update_strikes_count()
    return None

@webiopi.macro
def next_batter():
    sbfunc.next_batter()
    return None

@webiopi.macro
def show_batter_info():
    sbfunc.show_batter_info()
    return None

@webiopi.macro
def get_player_info():
    label = sbfunc.get_player_info()
    return label

@webiopi.macro
def decrease_next_batter():
    sbfunc.decrease_next_batter()
    return None

@webiopi.macro
def update_outs_count():
    sbfunc.update_outs_count()
    return None

@webiopi.macro
def update_given_run_counter(counter,direction):
    sbfunc.update_given_run_counter(counter,direction)
    return None

@webiopi.macro
def update_given_hits_count(team,direction):
    sbfunc.update_hits_count(team,direction,0)
    return None

@webiopi.macro
def update_given_error_count(team,direction):
    sbfunc.update_error_count(team,direction,0)
    return None

@webiopi.macro
def get_counter_value(counter):
    return str(sbfunc.get_counter_value(counter))

@webiopi.macro
def set_display_mode(mode):
    sbfunc.set_display_mode(int(mode))
    return None

@webiopi.macro
def get_display_mode():
    return int(sbvar.display_mode)

@webiopi.macro
def update_player(battingorder,number,given_name,family_name,position,hits,at_bats):
    sbfunc.update_player(battingorder,number,given_name,family_name,position,hits,at_bats)
    return None

@webiopi.macro
def start_new_game():
    sbfunc.start_new_game()
    return None

@webiopi.macro
def show_time(debug_label):
    sbfunc.show_time(debug_label)
    return None

@webiopi.macro
def set_time(time_string):
    sbfunc.set_time(time_string)
    return None

@webiopi.macro
def shutdown_scoreboard():
    sbfunc.shutdown_scoreboard()
    return None

@webiopi.macro
def restart_scoreboard():
    sbfunc.restart_scoreboard()
    return None
# END OF FILE